@@ -21,7 +21,7 @@ else
   local_leap=`tail -1 ${local_url}| awk '{ print $1"-"$2"-"$3 }'`;
   ls_folder=`dirname $local_url`
 fi
-remote_url="http://cdf.gsfc.nasa.gov/html/CDFLeapSeconds.txt"
+remote_url="https://cdf.gsfc.nasa.gov/html/CDFLeapSeconds.txt"
 isCurlAvail=`which curl`
 if [ `echo "$isCurlAvail" | grep -c "no "` -eq 1 ]; then
  `wget -q -O /tmp/CDFLeapSeconds.txt ${remote_url}`
@@ -49,7 +49,7 @@ if [ $localdate -lt $remotedate ]; then
   echo ""
   echo "Newer leap second(s) had been added to CDFLeapSeconds.txt at the CDF"
   echo "home page. Please update your CDF installation that includes the"
-  echo "latest CDFLeapSeconds.txt from http://cdf.gsfc.nasa.gov."
+  echo "latest CDFLeapSeconds.txt from https://cdf.gsfc.nasa.gov."
   echo ""
 else
   if [ $localdate -eq $remotedate ]; then
