@@ -1,5 +1,5 @@
 /******************************************************************************
-* Copyright 1996-2014 United States Government as represented by the
+* Copyright 1996-2016 United States Government as represented by the
 * Administrator of the National Aeronautics and Space Administration.
 * All Rights Reserved.
 ******************************************************************************/
@@ -57,6 +57,9 @@
 *                               CDFinsertVarRecorsByVarName.
 *   V3.12 28-May-14, M Liu      Added function items for record deletion:
 *                               r/zVAR__RECORDS_RENUMBER_.
+*   V3.13 20-Oct-16, M Liu      Added a new set CDFread functions with CDFdata
+*                               type. Moved a few functions from cdfdist.h to
+*                               here.
 ******************************************************************************/
 
 #if !defined(CDFh_INCLUDEd__)
@@ -68,6 +71,7 @@
 
 typedef void *CDFid;
 typedef long CDFstatus;
+typedef void *CDFdata;
 
 /******************************************************************************
 * CDF defined variables
@@ -95,7 +99,7 @@ static double *TT2000NULL = 0;
 #define CDF_ATTR_NAME_LEN256    256
 
 #define CDF_COPYRIGHT_LEN       256
-#define CDF_STATUSTEXT_LEN      160
+#define CDF_STATUSTEXT_LEN      200
 #define CDF_PATHNAME_LEN        512
 
 #define EPOCH_STRING_LEN	24
@@ -304,6 +308,8 @@ static double *TT2000NULL = 0;
 #define SOME_ALREADY_ALLOCATED		((CDFstatus) 1008)
 #define PRECEEDING_RECORDS_ALLOCATED	((CDFstatus) 1009)
 #define TT2000_CDF_MAYNEEDUPDATE        ((CDFstatus) 1010)
+#define BLOCKINGFACTOR_TOO_SMALL        ((CDFstatus) 1011)
+#define BLOCKINGFACTOR_TOO_SMALL2       ((CDFstatus) 1012)
 
 #define CDF_OK                          ((CDFstatus) 0)
 
@@ -442,6 +448,7 @@ static double *TT2000NULL = 0;
 #define CANNOT_INSERT_RECORDS           ((CDFstatus) (-2233))
 #define TT2000_USED_OUTDATED_TABLE      ((CDFstatus) (-2234))
 #define BADDATE_LEAPSECOND_UPDATED      ((CDFstatus) (-2235))
+#define FUNCTION_NOT_SUPPORTED          ((CDFstatus) (-2236))
 
 /******************************************************************************
 * Functions (for INTERNAL interface).
@@ -1695,6 +1702,15 @@ VISIBLE_PREFIX CDFstatus CDFputAttrEntry PROTOARGs((
 VISIBLE_PREFIX CDFstatus CDFgetAttrEntry PROTOARGs((
   CDFid id, int grzEntry, long attrNum, long entryNum, void *value
 ));
+VISIBLE_PREFIX void CDFdataFree PROTOARGs((CDFdata value));
+VISIBLE_PREFIX CDFstatus CDFreadgAttrEntry PROTOARGs((
+  CDFid id, long attrNum, long entryNum, long *dataType, long *numElms,
+  CDFdata *value
+));
+VISIBLE_PREFIX CDFstatus CDFreadzAttrEntry PROTOARGs((
+  CDFid id, long attrNum, long entryNum, long *dataType, long *numElms,
+  CDFdata *value
+));
 VISIBLE_PREFIX CDFstatus CDFdeleteAttrEntry PROTOARGs((
   CDFid id, int grzEntry, long attrNum, long entryNum
 ));
@@ -1733,6 +1749,24 @@ VISIBLE_PREFIX CDFstatus CDFputVarsRecordDatabyNames PROTOARGs((
 VISIBLE_PREFIX CDFstatus CDFgetVarAllRecordsByVarID PROTOARGs((
   CDFid id, int zVar, long varNum, void *buffer
 ));
+VISIBLE_PREFIX CDFstatus CDFgetzVarSpec PROTOARGs((
+  CDFid id, long varNum, long *dataType, long *numElems,
+  long *numDims, long *dimSizes, long *recVary, long *dimsVary 
+));
+VISIBLE_PREFIX CDFstatus CDFreadzVarPadValue PROTOARGs((
+  CDFid id, long varNum, long *dataType, long *numElms, CDFdata *buffer
+));
+VISIBLE_PREFIX CDFstatus CDFreadzVarAllByVarID PROTOARGs((
+  CDFid id, long varNum, long *numRecs, long *dataType, long *numElems,
+  long *numDims, long *dimSizes, long *recVary, long *dimsVary, 
+  CDFdata *buffer
+));
+VISIBLE_PREFIX CDFstatus CDFreadzVarDataByVarID PROTOARGs((
+  CDFid id, long varNum, long *numRecs, CDFdata *buffer
+));
+VISIBLE_PREFIX CDFstatus CDFreadzVarRangeDataByVarID PROTOARGs((
+  CDFid id, long varNum, long strNum, long stpNum, CDFdata *buffer
+));
 VISIBLE_PREFIX CDFstatus CDFputVarAllRecordsByVarID PROTOARGs((
   CDFid id, int zVar, long varNum, long numRec, void *buffer
 ));
@@ -1747,6 +1781,17 @@ VISIBLE_PREFIX CDFstatus CDFputVarRangeRecordsByVarID PROTOARGs((
 VISIBLE_PREFIX CDFstatus CDFgetVarAllRecordsByVarName PROTOARGs((
   CDFid id, char *varName, void *buffer
 ));
+VISIBLE_PREFIX CDFstatus CDFreadzVarAllByVarName PROTOARGs((
+  CDFid id, char *varName, long *numRecs, long *dataType, long *numElems,
+  long *numDims, long *dimSizes, long *recVary, long *dimsVary, 
+  CDFdata *buffer
+));
+VISIBLE_PREFIX CDFstatus CDFreadzVarDataByVarName PROTOARGs((
+  CDFid id, char *varName, long *numRecs, CDFdata *buffer
+));
+VISIBLE_PREFIX CDFstatus CDFreadzVarRangeDataByVarName PROTOARGs((
+  CDFid id, char *varName, long strNum, long stpNum, CDFdata *buffer
+));
 VISIBLE_PREFIX CDFstatus CDFputVarAllRecordsByVarName PROTOARGs((
   CDFid id, char *varName, long numRecs, void *buffer
 ));
@@ -1785,9 +1830,13 @@ VISIBLE_PREFIX int CDFgetValidateDebug PROTOARGs(());
 VISIBLE_PREFIX void ROWtoCOL PROTOARGs((
   void *iBuffer, void *oBuffer, long numDims, long dimSizes[], long nValueBytes
 ));
+VISIBLE_PREFIX int CDFelemSize PROTOARGs((long));
 VISIBLE_PREFIX void COLtoROW PROTOARGs((
   void *iBuffer, void *oBuffer, long numDims, long dimSizes[], long nValueBytes
 ));
+VISIBLE_PREFIX int CDFstrcmpIgCase PROTOARGs((char *string1, char *string2));
+VISIBLE_PREFIX char *CDFstrstrIgCase PROTOARGs((char *string1, char *string2));
+
 #if !defined(__CFM68K__) || defined(__USING_STATIC_LIBS__) || !defined(CFM68KDLL)
 VISIBLE_PREFIX void EPOCHbreakdown PROTOARGs((
   double epoch, long *year, long *month, long *day, long *hour, long *minute,
