@@ -78,8 +78,10 @@
 #      define MSVC67 
 #    endif
 #  endif
-#  if defined (_MSC_VER)
-#    define snprintf _snprintf
+#  if defined (_MSC_VER) && (_MSC_VER < 1900)
+#     define snprintf _snprintf
+#     define isnan(x) _isnan(x)
+#     define isinf(x) (!_finite(x))
 #  endif
 #endif
 
@@ -112,7 +114,8 @@
 #  define Mach
 #endif
 
-#if defined(__ppc__) || (defined(__APPLE__) && !defined(i386))
+#if defined(__ppc__) || (defined(__APPLE__) && !defined(i386) && \
+                         !defined(__x86_64__))
 #  define POWERPC
 #  define unix
 #  if defined(__MACH__)  	/* Mac OS X cc (gcc) */
@@ -120,7 +123,7 @@
 #  endif
 #endif
 
-#if (defined(__APPLE__) && defined(i386))
+#if defined(__APPLE__) && (defined(i386) || defined(__x86_64__))
 #  define unix
 #  define IBMPC
 #  define macosXintel
@@ -309,6 +312,10 @@
 #  endif
 #endif
 
+#if defined(__MACH__)
+#  include <mach-o/dyld.h>
+#endif
+
 #if defined(dos) || defined(win32) || defined(__MINGW32__)
 #  include <stdlib.h>
 #  include <stdio.h>
@@ -319,6 +326,7 @@
 #  if defined(win32)
 #    include <io.h>
 #    include <fcntl.h>
+/*#    include <Windows.h> */
 #  endif
 #  if defined(BORLANDC)
 #    include <dir.h>
@@ -328,6 +336,7 @@
 #  endif
 #  if defined(__MINGW32__)
 #    include <dirent.h>
+#    include <unistd.h>
 #  endif
 #  include <conio.h>
 #  include <sys\types.h>
@@ -412,7 +421,7 @@ typedef unsigned short uShort;
 typedef unsigned int uInt4;
 typedef unsigned long uLongx;
 
-#if defined(alphaosf) || defined(IRIX64bit) || defined(SOLARIS64) || \
+#if defined(alphaosf) || defined(IRIX64bit) || defined(_LP64) || \
     defined(__amd64) || defined(__x86_64__) || defined(__ia64__) || \
     defined(AIX64) || defined(HP64) || defined(__PPC64__) || \
     defined(__ppc64__)
@@ -657,7 +666,8 @@ ap = _apT_; \
 #endif
 
 #if defined(unix)
-#  if (defined(sun) && !defined(SOLARIS)) || defined(sgi)
+#  if (defined(sun) && (!defined(_SUNOS_VTOC_8) && !defined(_SUNOS_VTOC_16))) \
+      || defined(sgi)
 #    define memmove(dst,src,nbytes) bcopy(src,dst,nbytes)
 #  endif
 #endif
@@ -787,6 +797,30 @@ ap = _apT_; \
 #define STRINGdataType(dataType) \
 (dataType == CDF_CHAR || dataType == CDF_UCHAR)
 
+/******************************************************************************
+* CDFstringDataType.
+*    Macro to check if a character string data type.
+******************************************************************************/
+
+#define CDFstringDataType(dataType) \
+(dataType == CDF_CHAR || dataType == CDF_UCHAR)
+
+/******************************************************************************
+* CDFintDataType.
+*    Macro to check if one of the CDF integer data types.
+******************************************************************************/
+
+#define CDFintDataType(dataType) \
+(dataType == CDF_INT1 || dataType == CDF_UINT1 || dataType == CDF_INT2 || dataType == CDF_UINT2 || dataType == CDF_INT4 || dataType == CDF_UINT4 || dataType == CDF_INT8)
+
+/******************************************************************************
+* CDFfloatDataType.
+*    Macro to check if one of the CDF float data types.
+******************************************************************************/
+
+#define CDFfloatDataType(dataType) \
+(dataType == CDF_REAL4 || dataType == CDF_REAL8 || dataType == CDF_FLOAT || dataType == CDF_DOUBLE)
+
 /******************************************************************************
 * CDFepochDataType.
 *    Macro to check if one of the CDF epoch data types.
@@ -1000,7 +1034,6 @@ VISIBLE_PREFIX char *strcatX PROTOARGs((char *dst, char *src, size_t max));
   }
 #endif
 
-VISIBLE_PREFIX int CDFelemSize PROTOARGs((long));
 VISIBLE_PREFIX void ClearBytes PROTOARGs((
   void *buffer, int firstByte, int lastByte
 ));
