@@ -1,5 +1,5 @@
 /******************************************************************************
-* Copyright 1996-2013 United States Government as represented by the
+* Copyright 1996-2014 United States Government as represented by the
 * Administrator of the National Aeronautics and Space Administration.
 * All Rights Reserved.
 ******************************************************************************/
@@ -34,7 +34,7 @@
 /*  On machines where "long" is 64 bits, we need to declare
     uint32 as something guaranteed to be 32 bits.  */
 
-#if defined(alphaosf) || defined(IRIX64bit) || defined(SOLARIS64) || \
+#if defined(alphaosf) || defined(IRIX64bit) || defined(_LP64) || \
     defined(__amd64) || defined(__x86_64__) || defined(__ia64__) || \
     defined(__PPC64__) || defined(__ppc64__)
 typedef unsigned int uint32;
