@@ -67,6 +67,7 @@
 #define ABOUTqual		20
 #define STATSqual		21
 #define NOSTATSqual		22
+#define EPOCH_MONOTONICqual	23
 
 /******************************************************************************
 * Constants.
@@ -93,6 +94,7 @@ Logical updateMonotonic;
 Logical useFormat;
 Logical rangeCheck;
 Logical ignoreFills;
+Logical epochMonotonic;
 FILE *OUTfp;
 long validminAttrN;			/* attribute number */
 long validmaxAttrN;			/* attribute number */
@@ -106,6 +108,7 @@ extern Logical updateMonotonic;
 extern Logical useFormat;
 extern Logical rangeCheck;
 extern Logical ignoreFills;
+extern Logical epochMonotonic;
 extern FILE *OUTfp;
 extern long validminAttrN;			/* attribute number */
 extern long validmaxAttrN;			/* attribute number */
@@ -163,10 +166,11 @@ void DisplayMin PROTOARGs((struct VarStruct *));
 void DisplayMax PROTOARGs((struct VarStruct *));
 void DisplayFill PROTOARGs((struct VarStruct *));
 Logical SetupVar PROTOARGs((struct VarStruct *));
-Logical CALCstat PROTOARGs((struct VarStruct *));
-void DISPstat PROTOARGs((struct VarStruct *));
+Logical CALCstat PROTOARGs((struct VarStruct *, int));
+void DISPstat PROTOARGs((struct VarStruct *, int));
 void FreeVarMem PROTOARGs((struct VarStruct *Var));
 Logical StatusHandlerStats PROTOARGs((CDFstatus));
+Logical HandleVirtual PROTOARGs((struct VarStruct *Var));
 
 /*****************************************************************************/
 
