@@ -1,5 +1,5 @@
 /******************************************************************************
-* Copyright 1996-2013 United States Government as represented by the
+* Copyright 1996-2014 United States Government as represented by the
 * Administrator of the National Aeronautics and Space Administration.
 * All Rights Reserved.
 ******************************************************************************/
@@ -164,7 +164,7 @@
 
 #define QOP_MAX_ARGVs	40
 #define QOP_MAX_PARMs	40
-#define QOP_MAX_QUALs	35
+#define QOP_MAX_QUALs	40
 
 /*****************************************************************************
 * QOP structure.
@@ -189,7 +189,7 @@ char *qualOpt[QOP_MAX_QUALs];
 * Format specifiers.
 ******************************************************************************/
 
-#if defined(alphaosf) || defined(IRIX64bit) || defined(SOLARIS64) || \
+#if defined(alphaosf) || defined(IRIX64bit) || defined(_LP64) || \
     defined(__amd64) || defined(__x86_64__) || defined(__ia64__) || \
     defined(__PPC64__) || defined(__ppc64__)
 #  define Int32FORMAT	"%d"
@@ -646,6 +646,7 @@ extern int lastSecond;
 * Function prototypes.
 *****************************************************************************/
 
+int UTF8StrLength PROTOARGs((unsigned char *));
 void ASSIGNx PROTOARGs((void *, void *, long, long));
 Logical EQx PROTOARGs((void *, void *, long, long));
 Logical NEx PROTOARGs((void *, void *, long, long));
@@ -765,6 +766,15 @@ Logical S3qualifierLong PROTOARGs((
   QOP *qop, long *variable, int S1x, long S1, int S2x, long S2, int S3x,
   long S3, long defaultS, char *conflictText
 ));
+Logical S4qualifierLong PROTOARGs((
+  QOP *qop, long *variable, int S1x, long S1, int S2x, long S2, int S3x,
+  long S3, int S4x, long S4, long defaultS, char *conflictText
+));
+Logical S6qualifierLong PROTOARGs((
+  QOP *qop, long *variable, int S1x, long S1, int S2x, long S2, int S3x,
+  long S3, int S4x, long S4, int S5x, long S5, int S6x, long S6, 
+  long defaultS, char *conflictText
+));
 void BlankPadRight PROTOARGs((char *string, int count));
 CDFstatus GetFormatEntry PROTOARGs((Logical, long, char **));
 Logical ParseOptionList PROTOARGs((
@@ -854,6 +864,15 @@ int GetNumTokens PROTOARGs((int token, char *string));
 Logical ValidateQual PROTOARGs((
   char *qual, char *validQuals[]
 ));
+void DisplayCDFdata PROTOARGs((
+  long dataType, long numElems, void *value
+));
+int BinarySearch PROTOARGs((
+  long dataType, void *values, void *value, int min, int max
+));
+void MergeSort PROTOARGs((
+  long dataType, void *values, void *tmp, int left, int right
+));
 #if defined(mac)
 void MacExecuteSO PROTOARGs((
   Logical (*exeFnc)(int argC, char *argV[]),
@@ -931,6 +950,10 @@ void DebugMessage PROTOARGs((char *text));
 }
 #endif
 
+#if defined(vms)
+#define isinf(x) (!finite(x))
+#endif
+
 /*****************************************************************************/
 
 #endif
