@@ -1,4 +1,9 @@
 /******************************************************************************
+* Copyright 1996-2014 United States Government as represented by the
+* Administrator of the National Aeronautics and Space Administration.
+* All Rights Reserved.
+******************************************************************************/
+/******************************************************************************
 *
 *  NSSDC/CDF                                        CDF `check sum' operations.
 *
@@ -19,17 +24,17 @@
 * Local function prototypes.
 ******************************************************************************/
 CDFstatus AddChecksumMD5 PROTOARGs((vFILE *vFp, long size,
-                                    unsigned char *signature));
+                                    uChar *signature));
 CDFstatus AddChecksumMD5_64 PROTOARGs((vFILE *vFp, OFF_T size,
-                                       unsigned char *signature));
+                                       uChar *signature));
 CDFstatus ComputeChecksumMD5 PROTOARGs((vFILE *vFp, long size,
-                                        unsigned char *signature));
+                                        uChar *signature));
 CDFstatus ComputeChecksumMD5_64 PROTOARGs((vFILE *vFp, OFF_T size,
-                                           unsigned char *signature));
+                                           uChar *signature));
 CDFstatus GetChecksumMD5 PROTOARGs((vFILE *vFp, long size, 
-                                    unsigned char *signature));
+                                    uChar *signature));
 CDFstatus GetChecksumMD5_64 PROTOARGs((vFILE *vFp, OFF_T size,
-                                       unsigned char *signature));
+                                       uChar *signature));
 CDFstatus AddChecksum PROTOARGs((struct CDFstruct *CDF));
 CDFstatus AddChecksum64 PROTOARGs((struct CDFstruct *CDF));
 CDFstatus VerifyChecksum PROTOARGs((struct CDFstruct *CDF));
@@ -42,12 +47,12 @@ CDFstatus VerifyChecksum64 PROTOARGs((struct CDFstruct *CDF));
 CDFstatus AddChecksumMD5 (vFp, size, signature)
 vFILE *vFp;
 long  size;
-unsigned char signature[16];
+uChar signature[16];
 {
   
 #if defined(vms)
   size_t lastBlk;
-  unsigned char buffer[512];
+  uChar buffer[512];
   int i, j, inBlk, cross= 0;
   inBlk = size % 512;
   lastBlk = (size_t) 512 * (size / 512);
@@ -117,7 +122,7 @@ unsigned char signature[16];
 CDFstatus AddChecksumMD5_64 (vFp, size, signature)
 vFILE *vFp;
 OFF_T  size;
-unsigned char signature[16];
+uChar signature[16];
 {    
 
 #if defined(win32) && (_FILE_OFFSET_BITS == 64)
@@ -133,7 +138,7 @@ unsigned char signature[16];
   else {
 #   if defined(vms)
       OFF_T lastBlk;
-      unsigned char buffer[512];
+      uChar buffer[512];
       int i, j, inBlk, cross= 0;
       inBlk = size % 512;
       lastBlk = (OFF_T) 512 * (size / 512);
@@ -212,9 +217,9 @@ unsigned char signature[16];
 CDFstatus ComputeChecksumMD5 (vFp, size, signature)
 vFILE *vFp;
 long  size;
-unsigned char  signature[16];
+uChar  signature[16];
 {
-  unsigned char buffer[BUFFSIZE];
+  uChar buffer[BUFFSIZE];
   struct MD5Context md5c;
   int jj = 0, readBytes;
 
@@ -239,9 +244,9 @@ unsigned char  signature[16];
 CDFstatus ComputeChecksumMD5_64 (vFp, size, signature)
 vFILE *vFp;
 OFF_T  size;
-unsigned char  signature[16];
+uChar  signature[16];
 {
-  unsigned char buffer[BUFFSIZE];
+  uChar buffer[BUFFSIZE];
   struct MD5Context md5c;
   OFF_T jj = 0; 
   int readBytes;
@@ -275,7 +280,7 @@ unsigned char  signature[16];
 CDFstatus GetChecksumMD5 (vFp, size, signature)
 vFILE *vFp;
 long  size;
-unsigned char signature[16];
+uChar signature[16];
 { 
 
   if (fseek(vFp->fp,size,vSEEK_SET) == EOF) return FALSE;
@@ -290,7 +295,7 @@ unsigned char signature[16];
 CDFstatus GetChecksumMD5_64 (vFp, size, signature)
 vFILE *vFp;
 OFF_T  size;
-unsigned char *signature;
+uChar *signature;
 {
 
 #if defined(win32) && (_FILE_OFFSET_BITS == 64)
@@ -329,7 +334,7 @@ struct CDFstruct *CDF;
   Int32 CDRflags;
   long CCRsize, CPRsize, usedSize; 
   CDFstatus pStatus = CDF_OK;
-  unsigned char signature[16], csig[16];
+  uChar signature[16], csig[16];
 
   if (!sX(ReadCDR(CDF->fp,V2_CDR_OFFSET,
                   CDR_FLAGS,&CDRflags,
@@ -389,7 +394,7 @@ struct CDFstruct *CDF;
   Int32 CDRflags;
   OFF_T CCRsize, CPRsize, usedSize;
   CDFstatus pStatus = CDF_OK;
-  unsigned char signature[16], csig[16];
+  uChar signature[16], csig[16];
 
   if (!sX(ReadCDR64(CDF->fp,V3_CDR_OFFSET64,
                     CDR_FLAGS,&CDRflags,
@@ -460,7 +465,7 @@ struct CDFstruct *CDF;
   Int32 CDRflags;
   long CCRsize, CPRsize, usedSize; 
   CDFstatus pStatus = CDF_OK;
-  unsigned char signature[16];
+  uChar signature[16];
 
   if (!sX(ReadCDR(CDF->fp,V2_CDR_OFFSET,
                   CDR_FLAGS,&CDRflags,
@@ -519,7 +524,7 @@ struct CDFstruct *CDF;
   Int32 CDRflags;
   OFF_T CCRsize, CPRsize, usedSize; 
   CDFstatus pStatus = CDF_OK;
-  unsigned char signature[16];
+  uChar signature[16];
 
   if (!sX(ReadCDR64(CDF->fp,V3_CDR_OFFSET64,
                     CDR_FLAGS,&CDRflags,
