@@ -478,8 +478,8 @@ switch (Va->item) {
     int entryType = E3p(Va->item,gENTRY_EXISTENCE_,
 				 rENTRY_EXISTENCE_,
 				 zENTRY_EXISTENCE_);
-    struct CDFstruct *CDF; Logical zEntry;
-    long entryNum = va_arg (Va->ap, long), entryN;
+    struct CDFstruct *CDF; Logical zEntry = FALSE;
+    long entryNum = va_arg (Va->ap, long), entryN = -1L;
     SelectCDF (Cur->cdf, CDF)
     if (!CURRENTattrSELECTED64(CDF)) return NO_ATTR_SELECTED;
     if (!sX(CheckEntryOp64(CDF,entryType),&pStatus)) return pStatus;
