@@ -1,5 +1,5 @@
 /******************************************************************************
-* Copyright 1996-2013 United States Government as represented by the
+* Copyright 1996-2014 United States Government as represented by the
 * Administrator of the National Aeronautics and Space Administration.
 * All Rights Reserved.
 ******************************************************************************/
@@ -69,6 +69,7 @@ switch (Va->item) {
     Logical no_append = FALSE;
     uInt32 magicNumber1 = V2magicNUMBER_1;
     uInt32 magicNumber2u = V2magicNUMBER_2u;
+    char *del = NULL;
     /**************************************************************************
     * Get arguments for this operation/item.
     **************************************************************************/
@@ -98,7 +99,25 @@ switch (Va->item) {
     MakeUpperString (CDFnameT);
 #endif
     RemoveCDFFileExtension(CDFnameT, CDFnameTx);
+#if defined(unix) || defined(win32) || defined(dos)
+# if defined(unix)
+    del = strrchr(CDFnameTx, '/');
+# else
+    del = strrchr(CDFnameTx, '\\');
+    if (del == NULL) {
+#     if defined(win32)
+        del = strrchr(CDFnameTx, '/');
+#     endif
+    }
+# endif
+    if (del == NULL) {
+      if (!ValidCDFname(CDFnameTx)) return BAD_CDF_NAME;
+    } else {
+      if (!ValidCDFname(del+1)) return BAD_CDF_NAME;
+    }
+#else
     if (!ValidCDFname(CDFnameTx)) return BAD_CDF_NAME;
+#endif
     BuildFilePath (CDFt, CDFnameTx, no_append, upper_case_ext, version_numbers,
 		   INT32_ZERO, CDFnameX);
     if (IsReg(CDFnameX)) return CDF_EXISTS;
@@ -113,13 +132,13 @@ switch (Va->item) {
     CDF = (struct CDFstruct *) cdf_AllocateMemory ((size_t)sizeof(struct CDFstruct), NULL);
     if (CDF == NULL) {
       V_close (dotFp, NULL, NULL);
-      DeleteFile (CDFnameX);
+      CDFdeleteFile (CDFnameX);
       return BAD_MALLOC;
     }
     CDF->CDFname = (char *) cdf_AllocateMemory ((size_t)strlen(CDFnameTx) + 1, NULL);
     if (CDF->CDFname == NULL) {
       V_close (dotFp, NULL, NULL);
-      DeleteFile (CDFnameX);
+      CDFdeleteFile (CDFnameX);
       cdf_FreeMemory (CDF, NULL);
       return BAD_MALLOC;
     }
@@ -176,7 +195,7 @@ switch (Va->item) {
     * Set number of cache buffers based on the CDF's format.
     **************************************************************************/
     if (!CACHEv(CDF->fp,CDF->workingCacheSize)) {
-      AbortAccess (CDF, noUPDATE, DELETE);
+      AbortAccess (CDF, noUPDATE, CDFDELETE);
       cdf_FreeMemory (CDF, NULL);
       return BAD_CACHE_SIZE;
     }
@@ -184,12 +203,12 @@ switch (Va->item) {
     * Write magic numbers.
     **************************************************************************/
     if (!Write32(CDF->fp,(Int32 *)&magicNumber1)) {
-      AbortAccess (CDF, noUPDATE, DELETE);
+      AbortAccess (CDF, noUPDATE, CDFDELETE);
       cdf_FreeMemory (CDF, NULL);
       return CDF_WRITE_ERROR;
     }
     if (!Write32(CDF->fp,(Int32 *)&magicNumber2u)) {
-      AbortAccess (CDF, noUPDATE, DELETE);
+      AbortAccess (CDF, noUPDATE, CDFDELETE);
       cdf_FreeMemory (CDF, NULL);
       return CDF_WRITE_ERROR;
     }
@@ -221,7 +240,7 @@ switch (Va->item) {
     if (!sX(WriteCDR(CDF->fp,V2_CDR_OFFSET,
 		     CDR_RECORD,&CDR,copyRight,
 		     CDR_NULL),&pStatus)) {
-      AbortAccess (CDF, noUPDATE, DELETE);
+      AbortAccess (CDF, noUPDATE, CDFDELETE);
       cdf_FreeMemory (CDF, NULL);
       return pStatus;
     }
@@ -250,7 +269,7 @@ switch (Va->item) {
     if (!sX(WriteGDR(CDF->fp,CDF->GDRoffset,
 		     GDR_RECORD,&GDR,
 		     GDR_NULL),&pStatus)) {
-      AbortAccess (CDF, noUPDATE, DELETE);
+      AbortAccess (CDF, noUPDATE, CDFDELETE);
       cdf_FreeMemory (CDF, NULL);
       return pStatus;
     }
@@ -272,7 +291,7 @@ switch (Va->item) {
   case rVAR_:
   case zVAR_: {
     Logical zOp = (Va->item == zVAR_);
-    long *numOut, zNumDims, *zDimSizes, recVariance,
+    long *numOut, zNumDims = 0, *zDimSizes = NULL, recVariance,
 	 *dimVariances, newVarNum, numDims;
     char *name, Tname[CDF_VAR_NAME_LEN+1], pathnameX[DU_MAX_PATH_LEN+1];
     struct CDFstruct *CDF;
@@ -282,7 +301,7 @@ switch (Va->item) {
     Int32 offset, ntlOffset, VDRhead, nVars;
     Int32 dataType, numElements;
     int dimN, *max;
-    Int32 padSize, toPad;
+    Int32 padSize;
     void *pad;
     name = va_arg (Va->ap, char *);
     dataType = (Int32) va_arg (Va->ap, long);
@@ -381,7 +400,7 @@ switch (Va->item) {
 	if (varFp == NULL) return VAR_CREATE_ERROR;
       }
       if (!CLOSEv(varFp,NULL, NULL)) {
-	DeleteFile (pathnameX);
+	CDFdeleteFile (pathnameX);
 	return VAR_CREATE_ERROR;
       }
     }
@@ -422,18 +441,17 @@ switch (Va->item) {
     padSize = (int) (CDFelemSize(dataType) * numElements);
     pad = (void *) cdf_AllocateMemory((size_t)padSize, NULL);
     if (!sX(AllocateIR(CDF,VDR.RecordSize+padSize,&offset),&pStatus)) {
-      DeleteFile (pathnameX);
+      CDFdeleteFile (pathnameX);
       AbortAccess (CDF, UPDATE, noDELETE);
       return pStatus;
     }
-    toPad = VDR.RecordSize;
     DefaultPadValuePre350(dataType, numElements, pad);
     VDR.RecordSize += padSize;
     SetBit32 (&VDR.Flags,VDR_PADVALUE_BIT);
     if (!sX(WriteVDR(CDF,CDF->fp,offset,zOp,
 		     VDR_RECORD,&VDR,pad,
 		     VDR_NULL),&pStatus)) {
-      DeleteFile (pathnameX);
+      CDFdeleteFile (pathnameX);
       AbortAccess (CDF, UPDATE, noDELETE);
       return pStatus;
     }
