@@ -1,5 +1,5 @@
 /******************************************************************************
-* Copyright 1996-2013 United States Government as represented by the
+* Copyright 1996-2014 United States Government as represented by the
 * Administrator of the National Aeronautics and Space Administration.
 * All Rights Reserved.
 ******************************************************************************/
@@ -963,6 +963,33 @@ Int32     *status;              /* Out: CDF status code. */
   return;
 }
 
+/******************************************************************************
+* CDF_delete_zvar_recs_renumber.
+******************************************************************************/
+VISIBLE_PREFIX
+Fif_PREFIXa
+void
+Fif_PREFIXb
+Fif_ENTRYPOINT(cdf_delete_zvar_recs_renumber__,
+               cdf_delete_zvar_recs_renumber_,
+               cdf_delete_zvar_recs_renumber,
+               CDF_DELETE_ZVAR_RECS_RENUMBER)
+(id, var_num, start_rec, end_rec, status)
+Int32     *id;                  /* In: CDF identifier. */
+Int32     *var_num;             /* In: zVariable number. */
+Int32     *start_rec;           /* In: zVariable's start record number. */
+Int32     *end_rec;             /* In: zVariable's end record number. */
+Int32     *status;              /* Out: CDF status code. */
+{
+  long startRec = (long) (*start_rec - 1);
+  long endRec = (long) (*end_rec - 1);
+  *status = (Int32) CDFlib (SELECT_, CDF_, Int32ToCDFid(*id),
+                                     zVAR_, (long) (*var_num -1),
+                            DELETE_, zVAR_RECORDS_RENUMBER_, startRec, endRec,
+                            NULL_);
+  return;
+}
+
 /******************************************************************************
 * CDF_insert_zvar_recs.
 ******************************************************************************/
@@ -2179,8 +2206,6 @@ Int32     *status;              /* Out: CDF status code. */
 Fif_GHOSTDEF(len)               /* Invisible length of "var_name"
                                    (generated by FORTRAN compiler). */
 {
-  int LFS = TRUE;
-  struct CDFstruct *CDF;
   struct STRINGstruct *ssh = NULL;
   *status = (Int32) CDFgetVarAllRecordsByVarName (Int32ToCDFid(*id),
 #if defined(Fif_DESCR)
@@ -2228,8 +2253,6 @@ Int32     *status;              /* Out: CDF status code. */
 Fif_GHOSTDEF(len)               /* Invisible length of "var_name"
                                    (generated by FORTRAN compiler). */
 {
-  int LFS = TRUE;
-  struct CDFstruct *CDF;
   struct STRINGstruct *ssh = NULL;
   *status = (Int32) CDFgetVarRangeRecordsByVarName (Int32ToCDFid(*id),
 #if defined(Fif_DESCR)
@@ -2334,8 +2357,6 @@ Int32     *status;              /* Out: CDF status code. */
 Fif_GHOSTDEF(len)               /* Invisible length of "var_name"
                                    (generated by FORTRAN compiler). */
 {
-  int LFS = TRUE;
-  struct CDFstruct *CDF;
   struct STRINGstruct *ssh = NULL;
   *status = (Int32) CDFputVarAllRecordsByVarName (Int32ToCDFid(*id),
 #if defined(Fif_DESCR)
@@ -2384,8 +2405,6 @@ Int32     *status;              /* Out: CDF status code. */
 Fif_GHOSTDEF(len)               /* Invisible length of "var_name"
                                    (generated by FORTRAN compiler). */
 {
-  int LFS = TRUE;
-  struct CDFstruct *CDF;
   struct STRINGstruct *ssh = NULL;
   *status = (Int32) CDFputVarRangeRecordsByVarName (Int32ToCDFid(*id),
 #if defined(Fif_DESCR)
