@@ -56,7 +56,7 @@ switch (Va->item) {
     Int32 magicNumber1, magicNumber2; int i;
     long *cType, *cParms; 
     void *cFileSize, *uFileSize;
-    long cSize2, uSize2;
+    long cSize2 = 0L, uSize2 = 0L;
     OFF_T cSize3, uSize3;
     int whichVersion = 3;
     CDFpathP = va_arg (Va->ap, char *);
@@ -1443,7 +1443,7 @@ switch (Va->item) {
       of the pad value is greater than 16, it causes segmentation fault
       for the IDL CDF interface routine.
     ***********************************************************************/
-    if (dataType == CDF_CHAR ||  dataType == CDF_UCHAR) 
+    if (STRINGdataType(dataType)) 
           numElems = 1;
 
     if (PADvalueBITset(flags)) {
