@@ -463,9 +463,8 @@ void (*fatalFnc) PROTOARGs((char *msg));
 #if defined(BUILDINGforIDL)
   return calloc(nObjects,objSize);
 #else
-  size_t nBytes = nObjects * objSize, i;
+  size_t nBytes = nObjects * objSize;
   void *ptr = cdf_AllocateMemory (nBytes, fatalFnc);
-  /* if (ptr != NULL) for (i = 0; i < nBytes; i++) ((Byte1 *) ptr)[i] = 0; */
   if (ptr != NULL) memset (ptr, 0, nBytes);
   return ptr;
 #endif
