@@ -718,9 +718,13 @@ Logical *upper;         /* Should extensions be upper case? */
 Logical *version;       /* Should a version number of `;1' be appended? */
 {
   char pathT[DU_MAX_PATH_LEN+1];
+  size_t pathLen;
+
+  pathLen = strlen (path);
 
   strcpyX (pathT, path, DU_MAX_PATH_LEN);
-  strcatX (pathT, ".cdf", DU_MAX_PATH_LEN);
+  if (pathLen < 4 || strcmp(pathT+(pathLen-4), ".cdf") != 0)
+    strcatX (pathT, ".cdf", DU_MAX_PATH_LEN);
   if (IsReg(pathT)) {
     *no_append = FALSE;
     *upper = FALSE;
@@ -729,7 +733,8 @@ Logical *version;       /* Should a version number of `;1' be appended? */
   }
 
   strcpyX (pathT, path, DU_MAX_PATH_LEN);
-  strcatX (pathT, ".CDF", DU_MAX_PATH_LEN);
+  if (pathLen < 4 || strcmp(pathT+(pathLen-4), ".CDF") != 0)
+    strcatX (pathT, ".CDF", DU_MAX_PATH_LEN);
   if (IsReg(pathT)) {
     *no_append = FALSE;
     *upper = TRUE;
@@ -738,7 +743,8 @@ Logical *version;       /* Should a version number of `;1' be appended? */
   }
 
   strcpyX (pathT, path, DU_MAX_PATH_LEN);
-  strcatX (pathT, ".cdf;1", DU_MAX_PATH_LEN);
+  if (pathLen < 6 || !StrStrIgCaseX(pathT+(pathLen-6), ".cdf;1"))
+    strcatX (pathT, ".cdf;1", DU_MAX_PATH_LEN);
   if (IsReg(pathT)) {
     *no_append = FALSE;
     *upper = FALSE;
@@ -747,7 +753,8 @@ Logical *version;       /* Should a version number of `;1' be appended? */
   }
 
   strcpyX (pathT, path, DU_MAX_PATH_LEN);
-  strcatX (pathT, ".CDF;1", DU_MAX_PATH_LEN);
+  if (pathLen < 6 || !StrStrIgCaseX(pathT+(pathLen-6), ".CDF;1"))
+    strcatX (pathT, ".CDF;1", DU_MAX_PATH_LEN);
   if (IsReg(pathT)) {
     *no_append = FALSE;
     *upper = TRUE;
@@ -755,17 +762,21 @@ Logical *version;       /* Should a version number of `;1' be appended? */
     return CDF_OK;
   }
 
+/*
 #if defined(unix) || defined(dos) || defined(win32) 
+*/
+#if defined(win32) || defined(dos) 
   strcpyX (pathT, path, DU_MAX_PATH_LEN);
   MakeUpperString (pathT);
-  strcatX (pathT, ".CDF", DU_MAX_PATH_LEN);
+  if (pathLen < 4 || !StrStrIgCaseX(pathT+(pathLen-4), ".CDF"))
+    strcatX (pathT, ".CDF", DU_MAX_PATH_LEN);
   if (IsReg(pathT)) {
     *no_append = FALSE;
     *upper = TRUE;
     *version = FALSE;
     return CDF_OK;
   }
-
+/*
   strcpyX (pathT, path, DU_MAX_PATH_LEN);
   MakeUpperString (pathT);
   if (IsReg(pathT)) {
@@ -774,6 +785,7 @@ Logical *version;       /* Should a version number of `;1' be appended? */
     *version = FALSE;
     return CDF_OK;
   }
+*/
 #endif
 
   if (IsReg(path)) {
@@ -965,8 +977,6 @@ void *buffer;
 int firstByte;
 int lastByte;
 {
-  int i;
-  /* for (i = firstByte; i <= lastByte; i++) ((Byte1 *)buffer)[i] = 0; */
   memset ((Byte1 *)buffer+firstByte, 0, (size_t) (lastByte - firstByte + 1));
   return;
 }
@@ -1774,10 +1784,10 @@ struct CDFstruct *CDF;
 }
 
 /******************************************************************************
-* DeleteFile.
+* CDFdeleteFile.
 ******************************************************************************/
 
-STATICforIDL Logical DeleteFile (path)
+STATICforIDL Logical CDFdeleteFile (path)
 char *path;
 {
 #if defined(vms)
@@ -1870,7 +1880,7 @@ struct CDFstruct *CDF;
   if (CDF->dotFp == NULL) {
     BuildFilePath (CDFt, CDF->CDFname, CDF->no_append, CDF->upper_case_ext,
 		   CDF->version_numbers, INT32_ZERO, tmpFile);
-    if (!DeleteFile(tmpFile)) sX (CDF_DELETE_ERROR, &pStatus);
+    if (!CDFdeleteFile(tmpFile)) sX (CDF_DELETE_ERROR, &pStatus);
   }
   else {
     if (!DELETEv(CDF->dotFp,NULL)) sX (CDF_DELETE_ERROR, &pStatus);
@@ -1893,7 +1903,7 @@ struct CDFstruct *CDF;
        }
        BuildFilePath (Vt, CDF->CDFname, CDF->no_append, CDF->upper_case_ext,
 		      CDF->version_numbers, varN, tmpFile);
-       if (!DeleteFile(tmpFile)) sX (VAR_DELETE_ERROR, &pStatus);
+       if (!CDFdeleteFile(tmpFile)) sX (VAR_DELETE_ERROR, &pStatus);
     }
     for (varN = 0; varN < CDF->NzVars; varN++) {
        struct VarStruct *Var = CDF->zVars[varN];
@@ -1906,7 +1916,7 @@ struct CDFstruct *CDF;
        }
        BuildFilePath (Zt, CDF->CDFname, CDF->no_append, CDF->upper_case_ext,
 		      CDF->version_numbers, varN, tmpFile);
-       if (!DeleteFile(tmpFile)) sX (VAR_DELETE_ERROR, &pStatus);
+       if (!CDFdeleteFile(tmpFile)) sX (VAR_DELETE_ERROR, &pStatus);
     }
   }
   return pStatus;
@@ -2230,6 +2240,34 @@ vSTATS *vStats;		/* If NULL, initialize (to zero). */
   return;
 }
 
+/******************************************************************************
+* FillSpacesToString.
+* This function scans for Nul in a string buffer. If found, it fills space(s)
+* until the end of the number of elements. This happens when a string is
+* entered with a length shorter than the defined number of elements. The
+* buffer's size is a number of numElms, which could contain multiple strings.
+******************************************************************************/
+STATICforIDL void FillSpacesToString (buffer, totalBytes, numElems)
+char  *buffer;
+int   totalBytes;
+int   numElems;
+{
+  int i, j, k, l;
+/*  if ((totalBytes == numElems) && ((int)strlen(buffer) == totalBytes))
+      return; */
+  l = totalBytes / numElems;
+  for (i = 0; i < l; ++i) {
+/*  if ((int)strlen(buffer+i*numElems) >= numElems) continue; */
+    for (j = 0; j < numElems; ++j) {
+      if (*(buffer+i*numElems+j) == '\0') {
+        for (k = j; k < numElems; ++k)
+          *(buffer+i*numElems+k) = ' ';
+        break;
+      }
+    }
+  }
+  return;
+}
 /******************************************************************************
 * DisplayVs.
 ******************************************************************************/
