@@ -392,6 +392,48 @@ CDFstatus *pStatus;     /* Returned status. */
 #endif
 }
 
+/******************************************************************************
+* UpdateTT2000header.
+* The leap second last updated header is to be updated from the leap second
+* table if it is an earlier day (not zero).
+******************************************************************************/
+
+STATICforIDL Logical UpdateTT2000header (CDF, pStatus)
+struct CDFstruct *CDF;
+CDFstatus *pStatus;
+{
+   long year, month, day;
+   Int32 tLastUpdated, tLastUpdated2;
+   /***************************************************************************
+   * Check if updated already.
+   ***************************************************************************/
+   if (CDF->tt2000Updated == 1) return TRUE;
+   if (!sX(ReadGDR64(CDF->fp,CDF->GDRoffset64,
+                     GDR_LEAPSECONDLASTUPDATED,&tLastUpdated,
+                     GDR_NULL),pStatus)) {
+     AbortAccess64 (CDF, noUPDATE, noDELETE);
+     return FALSE;
+   }
+   if (tLastUpdated != 0) {
+#if defined(vms)
+     CDFgetLastDateinLeapSecondsTBL (&year, &month, &day);
+#else
+     CDFgetLastDateinLeapSecondsTable (&year, &month, &day);
+#endif
+     tLastUpdated2 = 10000*(Int32)year + 100*(Int32)month + (Int32)day;
+     if (tLastUpdated2 > tLastUpdated) { 
+       if (!sX(WriteGDR64(CDF->fp,CDF->GDRoffset64,
+                          GDR_LEAPSECONDLASTUPDATED,&tLastUpdated2,
+                          GDR_NULL),pStatus)) {
+         AbortAccess64 (CDF, noUPDATE, noDELETE);
+         return FALSE;
+       }
+     }
+   }
+   CDF->tt2000Updated = 1;
+   return TRUE;
+}
+
 /******************************************************************************
 * WriteBuffer64.
 *    Write occurs at current offset (assumed to have been set before this
@@ -1163,7 +1205,7 @@ struct CDFstruct *CDF;
   if (CDF->dotFp == NULL) {
     BuildFilePath (CDFt, CDF->CDFname, CDF->no_append, CDF->upper_case_ext,
                    CDF->version_numbers, INT32_ZERO, tmpFile);
-    if (!DeleteFile(tmpFile)) sX (CDF_DELETE_ERROR, &pStatus);
+    if (!CDFdeleteFile(tmpFile)) sX (CDF_DELETE_ERROR, &pStatus);
   }
   else {
     if (!DELETEv64(CDF->dotFp,NULL)) sX (CDF_DELETE_ERROR, &pStatus);
@@ -1186,7 +1228,7 @@ struct CDFstruct *CDF;
        }
        BuildFilePath (Vt, CDF->CDFname, CDF->no_append, CDF->upper_case_ext,
                       CDF->version_numbers, varN, tmpFile);
-       if (!DeleteFile(tmpFile)) sX (VAR_DELETE_ERROR, &pStatus);
+       if (!CDFdeleteFile(tmpFile)) sX (VAR_DELETE_ERROR, &pStatus);
     }
     for (varN = 0; varN < CDF->NzVars; varN++) {
        struct VarStruct *Var = CDF->zVars[varN];
@@ -1199,7 +1241,7 @@ struct CDFstruct *CDF;
        }
        BuildFilePath (Zt, CDF->CDFname, CDF->no_append, CDF->upper_case_ext,
                       CDF->version_numbers, varN, tmpFile);
-       if (!DeleteFile(tmpFile)) sX (VAR_DELETE_ERROR, &pStatus);
+       if (!CDFdeleteFile(tmpFile)) sX (VAR_DELETE_ERROR, &pStatus);
     }
   }
   return pStatus;
@@ -1455,7 +1497,7 @@ Logical zVar;
     if (!sX(WriteGDR64(CDF->fp,CDF->GDRoffset64,
                        GDR_LEAPSECONDLASTUPDATED,&LeapSecondLastUpdated,
                        GDR_NULL),&pStatus)) {
-      AbortAccess64 (CDF, noUPDATE, DELETE);
+      AbortAccess64 (CDF, noUPDATE, CDFDELETE);
       cdf_FreeMemory (CDF, NULL);
       return pStatus;
     }
