@@ -243,6 +243,7 @@ switch (Va->item) {
     CDF->zMode = zMODEoff;
     CDF->negToPosFp0 = FALSE;
     CDF->status = READ_ONLY;
+    CDF->tt2000Updated = 0;
     CDF->pseudo_clock = 0;
     CDF->stage.fp = NULL;
     CDF->stage.mark = ZERO_OFFSET;
@@ -387,7 +388,8 @@ switch (Va->item) {
                                    LIB_RELEASE_, &librel,
                                    LIB_INCREMENT_, &libinc,
                              NULL_);
-            if (PriorTo (vri, (Int32) libver, (Int32) librel, (Int32) libinc))
+            if (PriorTo(vri, (Int32)libver, (Int32)librel, (Int32)libinc) &&
+                PriorTo("3.5.0", (Int32)libver, (Int32)librel, (Int32)libinc))
               return UNABLE_TO_PROCESS_CDF;
             else
               return pStatus;
@@ -528,7 +530,10 @@ switch (Va->item) {
           return pStatus;
         }
     }
-    AddOpenCDFsCount();
+    if (!PriorTo ("3.5.0", version, release, increment)) {
+      int fileStatus = CDFgetLeapSecondsTableStatus();
+      AddOpenCDFsCount();
+    }
     break;
   }
   /****************************************************************************
@@ -551,12 +556,12 @@ static CDFstatus ValidateCDFTT2000 (CDFid id, int zVars, int rVars)
 {
   long maxRec, dataType;
   CDFstatus status;
-  int i, tt2000Sts;
-  long j, count;
+  int i, j, count, tt2000Sts;
   long long tt2000 = DEFAULT_TT2000_PADVALUE;
   void *buffer;
   long year, month, day, tt2000LastUpdated, numDims, dimSizes[CDF_MAX_DIMS];
   double yy, mm, dd, hh, mn, ss, ml, ms, ns;
+  int once;
 
   status = CDFgetLeapSecondLastUpdated (id, &tt2000LastUpdated);
   if (status != CDF_OK) return status;
@@ -567,6 +572,7 @@ static CDFstatus ValidateCDFTT2000 (CDFid id, int zVars, int rVars)
 #endif
   if (tt2000LastUpdated == 0 ||
       tt2000LastUpdated == (10000*year+100*month+day)) return CDF_OK;
+  once = 0;
   for (i = 0; i < zVars; ++i) {
     status = CDFlib(SELECT_, zVAR_, (long) i,
                     GET_, zVAR_DATATYPE_, &dataType,
@@ -577,13 +583,18 @@ static CDFstatus ValidateCDFTT2000 (CDFid id, int zVars, int rVars)
                     NULL_);
     if (status != CDF_OK) return status;
     if (maxRec < 0) continue;
+    /* If the file's last updated leap second date is later than table's, 
+       then, the table is out-dated. */
+    if ((once == 0) && (tt2000LastUpdated > (10000*year+100*month+day)))
+      return TT2000_USED_OUTDATED_TABLE;
+    else once = 1;
     status = CDFlib(GET_, zVAR_NUMDIMS_, &numDims,
                           zVAR_DIMSIZES_, dimSizes,
                     NULL_);
     if (status != CDF_OK) return status;
-    count = maxRec + 1;
+    count = (int) (maxRec + 1);
     if (numDims > 0)
-      for (j = 0; j < (int) numDims; ++j) count *= dimSizes[j];
+      for (j = 0; j < (int) numDims; ++j) count *= (int) dimSizes[j];
     buffer = (void *) malloc ((size_t) (count * sizeof(long long)));
     if (buffer == NULL) return BAD_MALLOC;
     status =  CDFgetVarAllRecordsByVarID (id, 1, (long) i, buffer);
@@ -611,9 +622,12 @@ static CDFstatus ValidateCDFTT2000 (CDFid id, int zVars, int rVars)
                     NULL_);
     if (status != CDF_OK) return status;
     if (maxRec < 0) continue;
-    count = maxRec + 1;
+    if ((once == 0) && (tt2000LastUpdated > (10000*year+100*month+day)))
+      return TT2000_USED_OUTDATED_TABLE;
+    else once = 1;
+    count = (int) (maxRec + 1);
     if (numDims > 0) 
-      for (j = 0; j < (int) numDims; ++j) count *= dimSizes[j];
+      for (j = 0; j < (int) numDims; ++j) count *= (int) dimSizes[j];
     buffer = (void *) malloc ((size_t) (count * sizeof(long long)));
     if (buffer == NULL) return BAD_MALLOC;
     status =  CDFgetVarAllRecordsByVarID (id, 0, (long) i, buffer);
