@@ -360,9 +360,11 @@ switch (Va->item) {
   case rVAR_COMPRESSION_:
   case zVAR_COMPRESSION_: {
     Logical zOp = (Va->item == zVAR_COMPRESSION_), zVar;
-    Int32 maxAllocated, pCount; int p; OFF_T VDRoffset;
+    Int32 maxAllocated, pCount = 0; int p; OFF_T VDRoffset;
     struct CDFstruct *CDF; struct VarStruct *Var;
     struct VDRstruct64 VDR; struct CPRstruct64 CPR;
+    Int32 numDims, dimSizes[CDF_MAX_DIMS], recSize;
+    int i;
     long cType = va_arg (Va->ap, long);         /* Compression type. */
     long *cParms = va_arg (Va->ap, long *);     /* Compression parameters. */
     /**************************************************************************
@@ -432,6 +434,29 @@ switch (Va->item) {
       if (cType != NO_COMPRESSION) return CANNOT_COMPRESS;
     }
     /**************************************************************************
+    * If the existing blocking factor is too small, then give warning.
+    **************************************************************************/
+    if (!zOp) {
+      if (!sX(ReadGDR64(CDF->fp,CDF->GDRoffset64,
+			GDR_rNUMDIMS,&numDims,
+			GDR_rDIMSIZES,dimSizes,
+			GDR_NULL),&pStatus)) {
+	AbortAccess64 (CDF, UPDATE, noDELETE);
+	return pStatus;
+      }
+    }
+    if (RECvaryBITset(VDR.Flags) && (VDR.blockingFactor != 0)) {
+      recSize = VDR.NumElems;
+      recSize *= (Int32) CDFelemSize(VDR.DataType);
+      for (i = 0; i < (int) (zOp?VDR.zNumDims:numDims); ++i) 
+	if (VDR.DimVarys[i]) recSize *= (zOp?VDR.zDimSizes[i]:dimSizes[i]);
+      if (VDR.blockingFactor < 
+	  (Int32) (MIN_BLOCKING_BYTES_compressed/recSize)) {
+	sX (BLOCKINGFACTOR_TOO_SMALL, &pStatus);
+/*	return pStatus; */
+      }
+    }
+    /**************************************************************************
     * Disable current compression (if any).
     **************************************************************************/
     if (VARcompressionBITset(VDR.Flags)) {
@@ -865,6 +890,9 @@ switch (Va->item) {
     }
     if (!sX(CheckEntryOp64(CDF,entryType),&pStatus)) return pStatus;
     if (!WriteAccess64(CDF,FALSE,&pStatus)) return pStatus;
+    if (dataType == CDF_TIME_TT2000) {
+      if (!UpdateTT2000header(CDF,&pStatus)) return pStatus;
+    }
     nBytesNew = (int) (CDFelemSize(dataType) * numElems);
     eOffset = E3(entryType,CDF->CURgrEntryOffset64,
 			   CDF->CURgrEntryOffset64,
