@@ -746,7 +746,7 @@ va_dcl
 #endif
 {
   long read_only_mode;
-  struct AEDRstructExt *CurAEDR;
+  struct AEDRstructExt *CurAEDR = NULL;
   va_list ap; CDFstatus pStatus = CDF_OK;
 #if defined(STDARG)
   va_start (ap, offset);
@@ -835,9 +835,14 @@ va_dcl
              if (!Read32(fp,&(AEDR->rfuD))) return CRE;
              if (!Read32(fp,&(AEDR->rfuE))) return CRE;
              if (value != NULL) {
-                 nBytes = (size_t) (CDFelemSize(AEDR->DataType) *
-                          AEDR->NumElems);
-                 if (!READv(value,nBytes,1,fp)) return CRE;
+               nBytes = (size_t) (CDFelemSize(AEDR->DataType) *
+                                  AEDR->NumElems);
+               if (!READv(value,nBytes,1,fp)) return CRE;
+               if (STRINGdataType(AEDR->DataType)) {
+                 FillSpacesToString((char *)value, (int)AEDR->NumElems,
+                                    (int)AEDR->NumElems);
+               }
+
              };
          }
          else
@@ -873,6 +878,9 @@ va_dcl
 	     if (!SEEKv(fp,tOffset,vSEEK_SET)) return CRE;
 	     nBytes = (size_t) (CDFelemSize(dataType) * numElems);
 	     if (!READv(value,nBytes,1,fp)) return CRE;
+             if (STRINGdataType(dataType)) {
+               FillSpacesToString((char *)value, (int)numElems, (int)numElems);
+             }
          }
          else
          {
@@ -1056,6 +1064,10 @@ va_dcl
 	 if (PADvalueBITset(VDR->Flags) && padValue != NULL) {
 	   size_t nBytes = (size_t) (CDFelemSize(VDR->DataType)*VDR->NumElems);
 	   if (!READv(padValue,nBytes,1,fp)) return CRE;
+           if (STRINGdataType(VDR->DataType)) {
+             FillSpacesToString((char *)padValue, (int)VDR->NumElems,
+                                (int)VDR->NumElems);
+           }
 	 }
 	 break;
        }
@@ -1151,6 +1163,10 @@ va_dcl
 	 if (!SEEKv(fp,tOffset,vSEEK_SET)) return CRE;
 	 nBytes = (size_t) (CDFelemSize(dataType) * numElems);
 	 if (!READv(padValue,nBytes,1,fp)) return CRE;
+         if (STRINGdataType(dataType)) {
+           FillSpacesToString((char *)padValue, (int)numElems,
+                              (int)numElems);
+         }
 	 break;
        }
        default: {
@@ -1731,6 +1747,11 @@ STATICforIDL CDFstatus ReadAEDRList (vFILE *fp,
       TempAEDR->Value = cdf_AllocateMemory((size_t)TempAEDR->ValueSize, NULL);
       if (TempAEDR->Value == NULL) return BAD_MALLOC;
       if (!READv(TempAEDR->Value,TempAEDR->ValueSize,1,fp)) return CRE;
+      if (STRINGdataType(TempAEDR->AEDR.DataType)) {
+        FillSpacesToString((char *)(TempAEDR->Value),
+                           (int)TempAEDR->AEDR.NumElems,
+                           (int)TempAEDR->AEDR.NumElems);
+      }
       ++iEntries;
       if (TempAEDR->AEDR.Num < 0 || TempAEDR->AEDR.Num > MaxEntry)
         return CV2C;
