@@ -206,7 +206,6 @@ va_dcl
        case CDR_RECORD: {
 	 struct CDRstruct64 *CDR = va_arg (ap, struct CDRstruct64 *);
 	 void *copyRight = va_arg (ap, char *);
-         Int32 actualEncoding;
 	 if (!SEEKv64(fp,offset,vSEEK_SET)) return CRE;
 	 if (!Read64_64(fp,&(CDR->RecordSize))) return CRE;
 	 if (!Read32_64(fp,&(CDR->RecordType))) return CRE;
@@ -869,7 +868,7 @@ va_dcl
 #endif
 {
   long read_only_mode;
-  struct AEDRstructExt64 *CurAEDR;
+  struct AEDRstructExt64 *CurAEDR = NULL;
   va_list ap; CDFstatus pStatus = CDF_OK;
 #if defined(STDARG)
   va_start (ap, offset);
@@ -962,8 +961,13 @@ va_dcl
                if (!Read32_64(fp,&(AEDR->rfuE))) return CRE;
              */
              if (value != NULL) {
-               nBytes = (size_t) (CDFelemSize(AEDR->DataType) * AEDR->NumElems);
+               nBytes = (size_t) (CDFelemSize(AEDR->DataType) *
+                                  AEDR->NumElems);
                if (!READv64(value,nBytes,1,fp)) return CRE;
+               if (STRINGdataType(AEDR->DataType)) {
+                 FillSpacesToString((char *)value, (int)AEDR->NumElems,
+                                    (int)AEDR->NumElems);
+               }
              };
          }
          else 
@@ -999,6 +1003,9 @@ va_dcl
 	     if (!SEEKv64(fp,tOffset,vSEEK_SET)) return CRE;
 	     nBytes = (size_t) (CDFelemSize(dataType) * numElems);
 	     if (!READv64(value,nBytes,1,fp)) return CRE;
+             if (STRINGdataType(dataType)) {
+               FillSpacesToString((char *)value, (int)numElems, (int)numElems);
+             }
          }
          else
          {
@@ -1199,6 +1206,10 @@ va_dcl
 	 if (PADvalueBITset(VDR->Flags) && padValue != NULL) {
 	   size_t nBytes = (size_t) (CDFelemSize(VDR->DataType)*VDR->NumElems);
 	   if (!READv64(padValue,nBytes,1,fp)) return CRE;
+           if (STRINGdataType(VDR->DataType)) {
+             FillSpacesToString((char *)padValue, (int)VDR->NumElems,
+                                (int)VDR->NumElems);
+           }
 	 }
 	 break;
        }
@@ -1289,6 +1300,10 @@ va_dcl
 	 if (!SEEKv64(fp,tOffset,vSEEK_SET)) return CRE;
 	 nBytes = (size_t) (CDFelemSize(dataType) * numElems);
 	 if (!READv64(padValue,nBytes,1,fp)) return CRE;
+         if (STRINGdataType(dataType)) {
+           FillSpacesToString((char *)padValue, (int)numElems,
+                              (int)numElems);
+         }
 	 break;
        }
        case VDR_RECORDSIZE:
@@ -1981,6 +1996,11 @@ STATICforIDL CDFstatus ReadAEDRList64 (vFILE *fp,
       TempAEDR->Value = cdf_AllocateMemory((size_t)TempAEDR->ValueSize, NULL);
       if (TempAEDR->Value == NULL) return BAD_MALLOC;
       if (!READv64(TempAEDR->Value,TempAEDR->ValueSize,1,fp)) return CRE;
+      if (STRINGdataType(TempAEDR->AEDR.DataType)) {
+        FillSpacesToString((char *)(TempAEDR->Value),
+                           (int)TempAEDR->AEDR.NumElems,
+                           (int)TempAEDR->AEDR.NumElems);
+      }
       ++iEntries;
       if (TempAEDR->AEDR.Num < 0 || TempAEDR->AEDR.Num > MaxEntry) {
         return CV3C;
