@@ -554,6 +554,54 @@ int c;
   return BOO(LowerCase(c),(c & 0x5F),c);
 }
 
+/******************************************************************************
+* CDFstrcmpIgCase.
+* It returns  1 if compared strings are identical with the same length
+*             0 if compared strings are not same or there is a NULL string
+******************************************************************************/
+
+int CDFstrcmpIgCase (string1, string2)
+char *string1;
+char *string2;
+{
+  size_t string1L, string2L;
+  int i;
+
+  if (string1 == NULL || string2 == NULL) return 0;
+  string1L = strlen(string1);
+  string2L = strlen(string2);
+  if (string1L != string2L) return 0;
+  for (i = 0; i < (int) string1L; i++) {
+     if (MakeLower(string1[i]) != MakeLower(string2[i]))
+       return 0;
+  }
+  return 1;
+}
+
+/******************************************************************************
+* CDFstrstrIgCase.
+******************************************************************************/
+
+char *CDFstrstrIgCase (string, substring)
+char *string;
+char *substring;
+{
+  size_t stringL, substringL;
+  int i, j;
+  
+  if (string == NULL || substring == NULL) return NULL;
+  stringL = strlen(string);
+  substringL = strlen(substring);
+  if (stringL == 0 || substringL == 0) return NULL;
+  if (stringL < substringL) return NULL;
+  for (i = 0; i < (int) stringL; i++) {
+     for (j = 0; j < (int) substringL; j++) {
+        if (MakeLower(substring[j]) != MakeLower(string[i+j])) break;
+     }
+     if (j == substringL) return &string[i];
+  }
+  return NULL;
+}
 
 /******************************************************************************
 * `strstr' (for SunOS before 4.1).  This should no longer be needed.  If it
