@@ -41,14 +41,7 @@
 /* Number of Delta(dAT) expressions before leap seconds were introduced */
 #define NERA1 14
 
-static int tableChecked = 0;
-static int openCDF64s = 0;
-static int toPlus = 0;
-static long currentDay = -1;
-static double currentLeapSeconds;
-static double currentJDay;
-static int fromFile = 0;
-
+#define LASTLEAPSECONDDAY	20170101
 /* Dates, Delta(AT)s and drift rates */
 static double  LTS [][6]= {
 /*      year month day    delta       drift      drift     */
@@ -92,7 +85,8 @@ static double  LTS [][6]= {
       { 2006,  1,   1, 33.0,             0.0, 0.0       },
       { 2009,  1,   1, 34.0,             0.0, 0.0       },
       { 2012,  7,   1, 35.0,             0.0, 0.0       },
-      { 2015,  7,   1, 36.0,             0.0, 0.0       }
+      { 2015,  7,   1, 36.0,             0.0, 0.0       },
+      { 2017,  1,   1, 37.0,             0.0, 0.0       }
      };
 
 /* Number of Delta(AT) in static table */
@@ -100,12 +94,21 @@ static const int NDAT = sizeof (LTS) / sizeof (LTS[0]);
 static double **LTD = NULL;
 static long long *NST = NULL;
 static int entryCnt;
+static char *leapTableEnv = NULL;
 
 static long doys1[] = {31,59,90,120,151,181,212,243,273,304,334,365};
 static long doys2[] = {31,60,91,121,152,182,213,244,274,305,335,366};
 static long daym1[] = {31,28,31,30,31,30,31,31,30,31,30,31};
 static long daym2[] = {31,29,31,30,31,30,31,31,30,31,30,31};
 
+static int tableChecked = 0;
+static int openCDF64s = 0;
+static int toPlus = 0;
+static long currentDay = -1;
+static double currentLeapSeconds;
+static double currentJDay;
+static int fromFile = 0;
+
 static double JulianDay12h (long, long, long);
 static void DatefromJulianDay (double, long *, long *, long *);
 static int ValidateYMD (long, long , long);
@@ -122,6 +125,7 @@ static int LeapSecondLastUpdatedinTable (int);
 static void FromUTCISO8601string (char *string, long *ly, long *lm, long *ld, 
                                   long *lh, long *ln, long *ls,
                                   long *ll, long *lu, long *la);
+static void RecheckLeapSecondsTableEnvVar ();
 
 static char *MonthToken (long month)
 {
@@ -244,13 +248,15 @@ void EPOCHbreakdownTT2000 (double epoch, long *year, long *month, long *day,
 
 static void LoadLeapSecondsTable ()
 {
-  if (!tableChecked) {
+
+  if (tableChecked == 0) {
     char *table;
     FILE *leaptable = NULL;
     int im, ix;
-    tableChecked = 1;
     table = CDFgetLeapSecondsTableEnvVar();
-    if (table != NULL) {
+    if (table != NULL && strlen(table) > 0) {
+      leapTableEnv = (char *) malloc (strlen(table)+1);
+      strcpy (leapTableEnv, table);
       leaptable = fopen (table, "r");
       if (leaptable != NULL) {
         int togo = 1;
@@ -287,7 +293,11 @@ static void LoadLeapSecondsTable ()
           entryCnt = count;
           fromFile = 1;
         }
-      }
+      } else
+        fromFile = 0;
+    } else {
+      leapTableEnv = NULL;
+      fromFile = 0;
     }
     if (fromFile == 0) {
       LTD = (double **) cdf_AllocateMemory (NDAT * sizeof (double *), NULL);
@@ -302,6 +312,7 @@ static void LoadLeapSecondsTable ()
       }
       entryCnt = NDAT;
     }
+    tableChecked = 1;
   }
 }
 
@@ -366,19 +377,40 @@ static double LeapSecondsfromJ2000 (long long nanosecs, int *leapSecond)
   return da;
 }
 
+static void RecheckLeapSecondsTableEnvVar ()
+{
+  char *table2;
+  if (openCDF64s != 0) return;
+  table2 = CDFgetLeapSecondsTableEnvVar();
+  if (table2 != NULL && strlen(table2) > 0) {
+    if (leapTableEnv != NULL && table2 != NULL &&
+        strcmp (leapTableEnv, table2) != 0) {
+        CDFClearLeapSecondsTable();
+        leapTableEnv = (char *) malloc (strlen(table2) + 1);
+        strcpy (leapTableEnv, table2);
+        LoadLeapSecondsTable();
+    }
+  } else {
+    CDFClearLeapSecondsTable();
+    leapTableEnv = NULL;
+    LoadLeapSecondsTable();
+  }
+}
+
 /******************************************************************************
 * CDFgetLeapSecondsTableEnvVar.
 ******************************************************************************/
     
 VISIBLE_PREFIX char *CDFgetLeapSecondsTableEnvVar ()
 {
-  char *table = NULL;
+    if (openCDF64s > 0) return leapTableEnv;
+    else {
 #if defined(vms)
-    table = getenv("CDF$LEAPSECONDSTABLE");
+      return getenv("CDF$LEAPSECONDSTABLE");
 #else
-    table = getenv("CDF_LEAPSECONDSTABLE");
+      return getenv("CDF_LEAPSECONDSTABLE");
 #endif
-    return table;
+    }
 }
 
 /******************************************************************************
@@ -388,15 +420,20 @@ VISIBLE_PREFIX char *CDFgetLeapSecondsTableEnvVar ()
 VISIBLE_PREFIX void CDFClearLeapSecondsTable ()
 {
   int ix;
-  if (LTD != NULL) {
+  if (openCDF64s == 0 && LTD != NULL) {
     for (ix = 0; ix < entryCnt; ++ix)
        cdf_FreeMemory (LTD[ix], NULL);
     cdf_FreeMemory (LTD, NULL);
     if (NST != NULL) cdf_FreeMemory (NST, NULL);
     LTD = NULL;
     NST = NULL;
+    tableChecked  = 0;
   }
-  tableChecked  = 0;
+  if (openCDF64s == 0 && leapTableEnv != NULL) {
+    free (leapTableEnv);
+    leapTableEnv = NULL;
+  }
+/*  tableChecked  = 0; */
 }
 
 /******************************************************************************
@@ -407,6 +444,7 @@ VISIBLE_PREFIX void CDFfillLeapSecondsTable (double **table)
 {
   int ix;
   if (LTD == NULL) LoadLeapSecondsTable();
+  else RecheckLeapSecondsTableEnvVar();
   for (ix = 0; ix < entryCnt; ++ix) {
     table[ix][0] = LTD[ix][0];
     table[ix][1] = LTD[ix][1];
@@ -424,6 +462,7 @@ VISIBLE_PREFIX void CDFfillLeapSecondsTable (double **table)
 VISIBLE_PREFIX int CDFgetRowsinLeapSecondsTable ()
 {
   if (LTD == NULL) LoadLeapSecondsTable();
+  else RecheckLeapSecondsTableEnvVar();
   return entryCnt;
 }
 
@@ -437,8 +476,9 @@ VISIBLE_PREFIX void CDFgetLastDateinLeapSecondsTBL (long *year, long *month,
 VISIBLE_PREFIX void CDFgetLastDateinLeapSecondsTable (long *year, long *month,
                                                       long *day)
 #endif
-{   
+{
   if (LTD == NULL) LoadLeapSecondsTable();
+  else RecheckLeapSecondsTableEnvVar();
   *year = (long) LTD[entryCnt-1][0];
   *month = (long) LTD[entryCnt-1][1];
   *day = (long) LTD[entryCnt-1][2];
@@ -449,8 +489,9 @@ VISIBLE_PREFIX void CDFgetLastDateinLeapSecondsTable (long *year, long *month,
 ******************************************************************************/
       
 VISIBLE_PREFIX int CDFgetLeapSecondsTableStatus ()
-{   
+{
   if (LTD == NULL) LoadLeapSecondsTable();
+  else RecheckLeapSecondsTableEnvVar();
   return fromFile;
 }
       
@@ -471,14 +512,11 @@ va_dcl
 {
   double epoch, *tmp, tmp1, dat0;
   long long t2, t3, secSinceJ2000;
-  long nansec, milsec;
-  double *ye, *ym, *da, *opt[6];
+  long nansec;
+  double *opt[6];
   long ye1, mo1, da1, ho1, mi1, se1, ml1, ma1, na1;
   int  ix, leapSec;
   va_list Va;
-  ye = ly;
-  ym = lm;
-  da = ld;
 #if defined(STDARG)
   va_start (Va, ld);
 #else
@@ -813,7 +851,7 @@ VISIBLE_PREFIX void encodeTT2000withBasedLeapDay (long long tt2000,
 
 VISIBLE_PREFIX long long parseTT2000withBasedLeapDay (char *tt2000, int yymmdd)
 {
-  long yy, mm, dd, hh, mn, ss, ms, us, ns;
+  long yy, mm, dd, hh, mn, ss, ms = 0L, us = 0L, ns = 0L;
   FromUTCISO8601string (tt2000, &yy, &mm, &dd, &hh, &mn, &ss, &ms, &us, &ns);
   return computeTT2000withBasedLeapDay ((double)yy, (double)mm, (double)dd,
 				        (double)hh, (double)mn, (double)ss,
@@ -842,8 +880,7 @@ va_dcl
   int ix;
   double ly, lm, ld, lh, ln, ls, ll, lu, la;
   long lyl, lml, ldl, lhl, lnl, lsl, lll, lul, lal;
-  double tmpy;
-  long xx, xy, xm, xd;
+  long xy, xm, xd;
   int lyear;
 
 #if defined(STDARG)
@@ -934,7 +971,6 @@ va_dcl
     if (opt[0] < 0.0) return ILLEGAL_TT2000_VALUE;
     tmp = opt[0];
     if (tmp > 0.0) {
-      tmp *= 24.0;
       lh = floor(tmp);
       tmp = (tmp - lh) * 60.0;
       ln = floor(tmp);
@@ -1155,8 +1191,6 @@ VISIBLE_PREFIX double CDF_TT2000_to_UTC_EPOCH (long long nanoSecSinceJ2000)
 
 VISIBLE_PREFIX long long CDF_TT2000_from_UTC_EPOCH (double epoch)
 {
-  long long nanosecSinceJ2000;
-  double millisec;
   long yy, mm, dd, hh, nn, ss, ll;
   if (epoch == -1.0E31 || epoch == -1.0E-31)
     return FILLED_TT2000_VALUE; 
@@ -1202,7 +1236,6 @@ VISIBLE_PREFIX double CDF_TT2000_to_UTC_EPOCH16 (long long nanoSecSinceJ2000,
 
 VISIBLE_PREFIX long long CDF_TT2000_from_UTC_EPOCH16 (double *epoch)
 {
-  long nasec;
   long yy, mm, dd, hh, nn, ss, ll, uu, aa, pp;
   if (epoch[0] == 0.0 && epoch[1] == 0.0) return DEFAULT_TT2000_PADVALUE;
   if (NegativeZeroReal8 (&(epoch[0])) && NegativeZeroReal8 (&(epoch[1])))
@@ -1369,8 +1402,20 @@ VISIBLE_PREFIX long long CDF_TT2000_from_UTC_string (char *string)
     else if (ly == 0 && lm == 1 && ld == 1 && tmp == 0)
       return DEFAULT_TT2000_PADVALUE;
     if (!YearWithin(ly) && !ValidateYMD(ly,lm,ld)) return ILLEGAL_TT2000_VALUE;
+    fraction *= 24.0;
+    lh = (long) floor(fraction);
+    fraction = (fraction - lh) * 60.0;
+    ln = (long) floor(fraction);
+    fraction = (fraction - ln) * 60.0;
+    ls = (long) floor(fraction);
+    fraction = (fraction - ls) * 1000.0;
+    ll = (long) floor(fraction);
+    fraction = (fraction - ll) * 1000.0;
+    lu = (long) floor(fraction);
+    la = (long) ((fraction - lu) * 1000.0);
     return CDF_TT2000_from_UTC_parts ((double) ly, (double) lm, (double) ld,
-                                      fraction, TT2000END);
+                                      (double) lh, (double) ln, (double) ls,
+                                      (double) ll, (double) lu, (double) la);
   } else if (format == 2) {
     if (sscanf(string,"%4ld%2ld%2ld%2ld%2ld%2ld",
         &ly, &lm, &ld, &lh, &ln, &ls) != 6) return ILLEGAL_TT2000_VALUE;
@@ -1427,7 +1472,7 @@ VISIBLE_PREFIX void AddOpenCDFsCount ()
 VISIBLE_PREFIX void ReduceOpenCDFsCount ()
 {
   --openCDF64s;
-  if (openCDF64s == 0) CDFClearLeapSecondsTable();
+  CDFClearLeapSecondsTable();
 }
 
 /******************************************************************************
@@ -1442,15 +1487,16 @@ VISIBLE_PREFIX void ReduceOpenCDFsCount ()
 * considered a bad data or case. 
 * It returns 0 as we can't tell if the time is good. It's using pre-3.6.0 code
 * with the latest leap second table, which is good. But 
-* using the older table, which can be bad after 2015-07-01).
+* using the older table, which can be bad after 2017-01-01).
 ******************************************************************************/
 
 VISIBLE_PREFIX int ValidateTT2000 (int yyyymmdd,
                                    int leapSecondLastUpdated)
 {
   int i, last, lastDate;
-  if (yyyymmdd < 20150701) return 1;
+  if (yyyymmdd < LASTLEAPSECONDDAY) return 1;
   if (LTD == NULL) LoadLeapSecondsTable ();
+  else RecheckLeapSecondsTableEnvVar();
   last = entryCnt - 1;
   lastDate = (int) (10000*LTD[last][0] + 100*LTD[last][1] + LTD[last][2]);
   if (leapSecondLastUpdated == lastDate) return 1;
@@ -1482,6 +1528,7 @@ VISIBLE_PREFIX int ValidateLeapSecondLastUpdated (int leapSecondLastUpdated)
 {
   int i, last;
   if (LTD == NULL) LoadLeapSecondsTable ();
+  else RecheckLeapSecondsTableEnvVar();
   last = entryCnt - 1;
   for (i = last; i >= 0; --i) {
     if (leapSecondLastUpdated == (int) (10000*LTD[i][0] + 100*LTD[i][1] +
