@@ -33,24 +33,34 @@
 * Local function prototypes.
 ******************************************************************************/
 
-static CDFstatus QuitCDF PROTOARGs((char *why, Int32 offset, int size, int num,
-void *value1, void *value2, Logical debug));
-static CDFstatus ValidateCCR PROTOARGs((vFILE *fp, Int32 offset, Logical debug));
-static CDFstatus ValidateCDR PROTOARGs((vFILE *fp, Int32 offset, Logical debug));
-static CDFstatus ValidateGDR PROTOARGs((vFILE *fp, Int32 offset, Logical debug));
-static CDFstatus ValidateVDR PROTOARGs((struct CDFstruct *CDF, vFILE *fp, Int32 offset, Logical zVar, Logical debug));
-static CDFstatus ValidateVXR PROTOARGs((vFILE *fp, Int32 offset, Int32 lastRec, Logical debug));
-static CDFstatus ValidateVVR PROTOARGs((vFILE *fp, Int32 offset, Logical debug));
-static CDFstatus ValidateADR PROTOARGs((struct CDFstruct *CDF, vFILE *fp, Int32 offset, Logical debug));
-static CDFstatus ValidateAEDR PROTOARGs((struct CDFstruct *CDF, vFILE *fp, Int32 offset, Int32 num, Int32 maxEntry, Logical zEntry, Logical debug));
-static CDFstatus ValidateCPR PROTOARGs((vFILE *fp, Int32 offset, Logical debug));
-static CDFstatus ValidateSPR PROTOARGs((vFILE *fp, Int32 offset, Logical debug));
-static CDFstatus ValidateCVVR PROTOARGs((vFILE *fp, Int32 offset, Logical debug));
-static CDFstatus ValidateUIR PROTOARGs((vFILE *fp, Int32 offset, Logical debug));
-static CDFstatus ValidateAttributeLinks PROTOARGs((struct CDFstruct *CDF, vFILE *fp, Logical debug));
-static CDFstatus ValidateAttributeEntryLink PROTOARGs((struct CDFstruct *CDF, vFILE *fp, Int32 num, Logical zEntry, Int32 AEDRhead, Int32 numEntries, Int32 maxEntry, Logical debug));
-static CDFstatus ValidateVariableLinks PROTOARGs((struct CDFstruct *CDF, vFILE *fp, Logical zVar, Logical debug));
-static CDFstatus ValidateVariableValueLinks PROTOARGs((struct CDFstruct *CDF, vFILE *fp, Int32 lastRec, Int32 headVXR, Logical debug));
+static CDFstatus QuitCDF PROTOARGs((char *, Int32, int, int, void *, void *,
+                                    Logical));
+static CDFstatus ValidateCCR PROTOARGs((vFILE *, Int32, Logical));
+static CDFstatus ValidateCDR PROTOARGs((vFILE *, Int32, Logical));
+static CDFstatus ValidateGDR PROTOARGs((vFILE *, Int32, Logical));
+static CDFstatus ValidateVDR PROTOARGs((struct CDFstruct *, vFILE *, Int32,
+                                        Logical, Logical));
+static CDFstatus ValidateVXR PROTOARGs((vFILE *, Int32, Int32, Logical));
+static CDFstatus ValidateVVR PROTOARGs((vFILE *, Int32, Logical));
+static CDFstatus ValidateADR PROTOARGs((struct CDFstruct *, vFILE *, Int32,
+                                        Logical));
+static CDFstatus ValidateAEDR PROTOARGs((struct CDFstruct *, vFILE *, Int32,
+                                         Int32, Int32, Logical, Logical));
+static CDFstatus ValidateCPR PROTOARGs((vFILE *, Int32, Logical));
+static CDFstatus ValidateSPR PROTOARGs((vFILE *, Int32, Logical));
+static CDFstatus ValidateCVVR PROTOARGs((vFILE *, Int32, Logical));
+static CDFstatus ValidateUIR PROTOARGs((vFILE *, Int32, Logical));
+static CDFstatus ValidateAttributeLinks PROTOARGs((struct CDFstruct *, vFILE *,
+                                                   Logical));
+static CDFstatus ValidateAttributeEntryLink PROTOARGs((struct CDFstruct *,
+                                                       vFILE *, Int32, Logical,
+                                                       Int32, Int32, Int32,
+                                                       Logical));
+static CDFstatus ValidateVariableLinks PROTOARGs((struct CDFstruct *, vFILE *,
+                                                  Logical, Logical));
+static CDFstatus ValidateVariableValueLinks PROTOARGs((struct CDFstruct *,
+                                                       vFILE *, Int32, Int32,
+                                                       Logical));
 static struct CDRstruct CDR;
 static struct GDRstruct GDR;
 static int rVars, zVars;
@@ -335,7 +345,6 @@ static CDFstatus ValidateCDR (vFILE *fp, Int32 offset, Logical debug)
 /*
   char copyRight[CDF_COPYRIGHT_LEN+1];
 */
-  int i;
   CDFstatus status;
  
   if (debug)
@@ -402,15 +411,15 @@ static CDFstatus ValidateGDR (vFILE *fp, Int32 offset, Logical debug)
     return QuitCDF ("CDF(GDR): NrVars or their link is invalid ", offset,
                     4, 1, &(GDR.NrVars), 0, debug);
   if (GDR.NumAttr < 0 || (GDR.NumAttr > 0 && GDR.ADRhead < 1)) 
-    return QuitCDF ("CDF(GDR): attribute numbers or their link is invalid ", offset,
-                    4, 1, &(GDR.NumAttr), 0, debug);
+    return QuitCDF ("CDF(GDR): attribute numbers or their link is invalid ",
+                    offset, 4, 1, &(GDR.NumAttr), 0, debug);
   if (GDR.rMaxRec < -1) 
     return QuitCDF ("CDF(GDR): max rVars record is invalid ", offset,
                     4, 1, &(GDR.rMaxRec), 0, debug);
   if (GDR.rNumDims < 0 ||
       GDR.rNumDims > CDF_MAX_DIMS) 
-    return QuitCDF ("CDF(GDR): number of dimensions for rVars is invalid ", offset,
-                    4, 1, &(GDR.rNumDims), 0, debug);
+    return QuitCDF ("CDF(GDR): number of dimensions for rVars is invalid ",
+                    offset, 4, 1, &(GDR.rNumDims), 0, debug);
   if (GDR.NzVars < 0 || (GDR.NzVars > 0 && GDR.zVDRhead < 1)) 
     return QuitCDF ("CDF(GDR): NzVars or their link is invalid ", offset,
                     4, 1, &(GDR.NzVars), 0, debug);
@@ -575,8 +584,7 @@ static CDFstatus ValidateVDR (struct CDFstruct *CDF, vFILE *fp, Int32 offset,
 		              Logical zVar, Logical debug)
 {
   struct VDRstruct VDR;
-  void *padValue;
-  Int32 nDims, numVars;
+  Int32 numVars;
   int ix;
   CDFstatus status;
   size_t nBytes;
@@ -671,19 +679,20 @@ static CDFstatus ValidateVXR (vFILE *fp, Int32 offset, Int32 lastRec,
                     4, 2, &(VXR.NusedEntries), &(VXR.Nentries), debug);
   if (VXR.VXRnext > 0) {
     if (VXR.Last[VXR.NusedEntries-1] > lastRec)
-      return QuitCDF ("CDF(VXR): a variable last record does not match in a Variable Index Record: ", offset,
-                      4, 2, &(VXR.Last[VXR.NusedEntries-1]), &lastRec, debug);
+      return QuitCDF ("CDF(VXR): a var's last record does not match in a VIR: ",
+                      offset, 4, 2, &(VXR.Last[VXR.NusedEntries-1]), &lastRec,
+                      debug);
     status = ValidateVXR (fp, VXR.VXRnext, lastRec, debug); 
     if (status != CDF_OK) return status;
   } else if (VXR.VXRnext < 0) {
-      return QuitCDF ("CDF(VXR): a link offset to next record is negative in a Variable Index Record: ", offset,
-                      4, 1, &(VXR.VXRnext), 0, debug);
+      return QuitCDF ("CDF(VXR): a link offset to next rec is negative in a VIR: ",
+                      offset, 4, 1, &(VXR.VXRnext), 0, debug);
   }
 
   for (i = 0; i < VXR.NusedEntries; ++i) {
     if (VXR.First[i] < 0 || VXR.Last[i] < 0 || VXR.First[i] > VXR.Last[i])
-      return QuitCDF ("CDF(VXR): entry value for first/last is invalid ", offset,
-                      4, 2, &(VXR.First[i]), &(VXR.Last[i]), debug);
+      return QuitCDF ("CDF(VXR): entry value for first/last is invalid ",
+                      offset, 4, 2, &(VXR.First[i]), &(VXR.Last[i]), debug);
     if (VXR.Offset[i] < 1) 
       return QuitCDF ("CDF(VXR): entry value for offset is invalid ", offset,
                       4, 1, &(VXR.Offset[i]), 0, debug);
@@ -720,7 +729,8 @@ static CDFstatus ValidateVVR (vFILE *fp, Int32 offset, Logical debug)
     return QuitCDF ("CDF(VVR): record type is invalid ", offset,
                     4, 1, &(VVR.RecordType), 0, debug);
   if (VVR.RecordSize < VVR_BASE_SIZE) 
-    return QuitCDF ("CDF(VVR): record size is invalid for Variable Value Record", offset,
+    return QuitCDF ("CDF(VVR): record size is invalid for Variable Value Record",
+                        offset,
                     4, 1, &(VVR.RecordSize), 0, debug);
   return CDF_OK;
 }
@@ -744,13 +754,16 @@ static CDFstatus ValidateUIR (vFILE *fp, Int32 offset, Logical debug)
     return QuitCDF ("CDF(UIR): record type is invalid ", offset,
                     4, 1, &(UIR.RecordType), 0, debug);
   if (UIR.RecordSize < UIR_BASE_SIZE) 
-    return QuitCDF ("CDF(UIR): record size is invalid for Unused Internal Record", offset,
+    return QuitCDF ("CDF(UIR): record size is invalid for Unused Internal Record",
+                        offset,
                     4, 1, &(UIR.RecordSize), 0, debug);
   if (UIR.NextUIR < 0) 
-    return QuitCDF ("CDF(UIR): offset to next UIR is invalid for Unused Internal Record", offset,
+    return QuitCDF ("CDF(UIR): offset to next UIR is invalid for Unused Internal Record",
+                        offset,
                     4, 1, &(UIR.NextUIR), 0, debug);
   if (UIR.PrevUIR < 0) 
-    return QuitCDF ("CDF(UIR): offset to previous UIR is invalid for Unused Internal Record", offset,
+    return QuitCDF ("CDF(UIR): offset to previous UIR is invalid for Unused Internal Record",
+                        offset,
                     4, 1, &(UIR.PrevUIR), 0, debug);
   return CDF_OK;
 }
@@ -792,7 +805,6 @@ static CDFstatus ValidateCCR (vFILE *fp, Int32 offset, Logical debug)
 static CDFstatus ValidateCPR (vFILE *fp, Int32 offset, Logical debug)
 {
   struct CPRstruct CPR;
-  int i;
   CDFstatus status;
   long cType, cParms[1];
 
@@ -879,7 +891,7 @@ static CDFstatus ValidateAttributeLinks (struct CDFstruct *CDF, vFILE *fp,
 {
   CDFstatus status;
   Int32 offset, nextADR, AgrEDRhead, AzEDRhead;
-  Int32 num, numgrEntries, maxgrEntry, numzEntries, maxzEntry, scope;
+  Int32 num, numgrEntries, maxgrEntry, numzEntries, maxzEntry;
   int ix, *visit;
 
   visit = (int *) cdf_AllocateMemory(GDR.NumAttr * sizeof(Int32), NULL);
@@ -921,7 +933,8 @@ static CDFstatus ValidateAttributeLinks (struct CDFstruct *CDF, vFILE *fp,
   for (ix = 0; ix < GDR.NumAttr; ++ix) {
     if (visit[ix] == 0) {
       cdf_FreeMemory (visit, NULL);
-      return QuitCDF ("CDF: an attribute unreachable in the attribute link: ", (Int32) -1,
+      return QuitCDF ("CDF: an attribute unreachable in the attribute link: ",
+                        (Int32) -1,
                        4, 1, &ix, 0, debug);
     }
   }
@@ -945,7 +958,8 @@ static CDFstatus ValidateAttributeEntryLink (struct CDFstruct *CDF, vFILE *fp,
 
   offset = EDRhead;
   lastNum = 0;
-  visits = (Int32 *) cdf_AllocateMemory ((size_t)numEntries * sizeof(Int32), NULL);
+  visits = (Int32 *) cdf_AllocateMemory ((size_t)numEntries * sizeof(Int32),
+                        NULL);
   if (visits == NULL) return BAD_MALLOC;
   for (ix = 0; ix < numEntries; ++ix) visits[ix] = 0;
   ix = 0;
@@ -963,15 +977,15 @@ static CDFstatus ValidateAttributeEntryLink (struct CDFstruct *CDF, vFILE *fp,
       for (iy = 0; iy < ix; ++iy) {
         if (visits[iy] == entryNum) { 
           cdf_FreeMemory (visits, NULL);
-          return QuitCDF ("CDF: entry number is repeating in an attribute entry link: ", (Int32) -1,
-                          4, 1, &entryNum, 0, debug);
+          return QuitCDF ("CDF: entry # is repeating in an attr entry link: ",
+                          (Int32) -1, 4, 1, &entryNum, 0, debug);
         }
       }
     }
     if (ix == (int) numEntries) {
       cdf_FreeMemory (visits, NULL);
-      return QuitCDF ("CDF: number of entries is more than maximum in an attribute entry link: ", (Int32) -1,
-                      4, 1, &ix, 0, debug);
+      return QuitCDF ("CDF: # of entries is more than max in an attr entry link: ",
+                      (Int32) -1, 4, 1, &ix, 0, debug);
     }
     visits[ix] = entryNum;
     ++ix;
@@ -980,8 +994,8 @@ static CDFstatus ValidateAttributeEntryLink (struct CDFstruct *CDF, vFILE *fp,
   }
   if (lastNum != maxEntry) {
     cdf_FreeMemory (visits, NULL);
-    return QuitCDF ("CDF: last entry number is not the maximum entry number in  an attribute entry link: ", (Int32) -1,
-                    4, 2, &lastNum, &maxEntry, debug);
+    return QuitCDF ("CDF: last entry # is not the max entry # in an attr entry link: ",
+                    (Int32) -1, 4, 2, &lastNum, &maxEntry, debug);
   }
   cdf_FreeMemory (visits, NULL);
   return CDF_OK;
@@ -1048,8 +1062,8 @@ static CDFstatus ValidateVariableLinks (struct CDFstruct *CDF, vFILE *fp,
   for (ix = 0; ix < numVars; ++ix) {
     if (visit[ix] == 0) {
       cdf_FreeMemory (visit, NULL);
-      return QuitCDF ("CDF: a variable unreachable in variable link: ", (Int32) -1,
-                       4, 1, &ix, 0, debug);
+      return QuitCDF ("CDF: a variable unreachable in variable link: ",
+                      (Int32) -1, 4, 1, &ix, 0, debug);
     }
   }
   cdf_FreeMemory (visit, NULL);
@@ -1060,11 +1074,11 @@ static CDFstatus ValidateVariableLinks (struct CDFstruct *CDF, vFILE *fp,
                       VDR_NULL);
     if (status == CDF_OK) {
       if (num >= numVars)
-        return QuitCDF ("CDF(VDR): a variable unreachable in variable link: ", offset,
-                        4, 2, &num, &numVars, debug);
+        return QuitCDF ("CDF(VDR): a variable unreachable in variable link: ",
+                        offset, 4, 2, &num, &numVars, debug);
       else
-        return QuitCDF ("CDF(VDR): a variable is repeated in variable link: ", offset,
-                        4, 2, &num, &numVars, debug);
+        return QuitCDF ("CDF(VDR): a variable is repeated in variable link: ",
+                        offset, 4, 2, &num, &numVars, debug);
     }
   }
   return CDF_OK;
