@@ -31,24 +31,34 @@
 * Local function prototypes.
 ******************************************************************************/
 
-static CDFstatus QuitCDF PROTOARGs((char *why, OFF_T offset, int size, int num,
-void *value1, void *value2, Logical debug));
-static CDFstatus ValidateCCR PROTOARGs((vFILE *fp, OFF_T offset, Logical debug));
-static CDFstatus ValidateCDR PROTOARGs((vFILE *fp, OFF_T offset, Logical debug));
-static CDFstatus ValidateGDR PROTOARGs((vFILE *fp, OFF_T offset, Logical debug));
-static CDFstatus ValidateVDR PROTOARGs((struct CDFstruct *CDF, vFILE *fp, OFF_T offset, Logical zVar, Logical debug));
-static CDFstatus ValidateVXR PROTOARGs((vFILE *fp, OFF_T offset, Int32 lastRec, Logical debug));
-static CDFstatus ValidateVVR PROTOARGs((vFILE *fp, OFF_T offset, Logical debug));
-static CDFstatus ValidateADR PROTOARGs((struct CDFstruct *CDF, vFILE *fp, OFF_T offset, Logical debug));
-static CDFstatus ValidateAEDR PROTOARGs((struct CDFstruct *CDF, vFILE *fp, OFF_T offset, Int32 num, Int32 maxEntry, Logical zEntry, Logical debug));
-static CDFstatus ValidateCPR PROTOARGs((vFILE *fp, OFF_T offset, Logical debug));
-static CDFstatus ValidateSPR PROTOARGs((vFILE *fp, OFF_T offset, Logical debug));
-static CDFstatus ValidateCVVR PROTOARGs((vFILE *fp, OFF_T offset, Logical debug));
-static CDFstatus ValidateUIR PROTOARGs((vFILE *fp, OFF_T offset, Logical debug));
-static CDFstatus ValidateAttributeLinks PROTOARGs((struct CDFstruct *CDF, vFILE *fp, Logical debug));
-static CDFstatus ValidateAttributeEntryLink PROTOARGs((struct CDFstruct *CDF, vFILE *fp, Int32 num, Logical zEntry, OFF_T AEDRhead, Int32 numEntries, Int32 maxEntry, Logical debug));
-static CDFstatus ValidateVariableLinks PROTOARGs((struct CDFstruct *CDF, vFILE *fp, Logical zVar, Logical debug));
-static CDFstatus ValidateVariableValueLinks PROTOARGs((struct CDFstruct *CDF, vFILE *fp, Int32 lastRec, OFF_T headVXR, Logical debug));
+static CDFstatus QuitCDF PROTOARGs((char *, OFF_T, int, int, void *, void *,
+                                    Logical));
+static CDFstatus ValidateCCR PROTOARGs((vFILE *, OFF_T, Logical));
+static CDFstatus ValidateCDR PROTOARGs((vFILE *, OFF_T, Logical));
+static CDFstatus ValidateGDR PROTOARGs((vFILE *, OFF_T, Logical));
+static CDFstatus ValidateVDR PROTOARGs((struct CDFstruct *, vFILE *, OFF_T,
+                                        Logical, Logical));
+static CDFstatus ValidateVXR PROTOARGs((vFILE *, OFF_T, Int32, Logical));
+static CDFstatus ValidateVVR PROTOARGs((vFILE *, OFF_T, Logical));
+static CDFstatus ValidateADR PROTOARGs((struct CDFstruct *, vFILE *, OFF_T,
+                                        Logical));
+static CDFstatus ValidateAEDR PROTOARGs((struct CDFstruct *, vFILE *, OFF_T,
+                                         Int32, Int32, Logical, Logical));
+static CDFstatus ValidateCPR PROTOARGs((vFILE *, OFF_T, Logical));
+static CDFstatus ValidateSPR PROTOARGs((vFILE *, OFF_T, Logical));
+static CDFstatus ValidateCVVR PROTOARGs((vFILE *, OFF_T, Logical));
+static CDFstatus ValidateUIR PROTOARGs((vFILE *, OFF_T, Logical));
+static CDFstatus ValidateAttributeLinks PROTOARGs((struct CDFstruct *, vFILE *,
+                                                   Logical));
+static CDFstatus ValidateAttributeEntryLink PROTOARGs((struct CDFstruct *,
+                                                       vFILE *, Int32, Logical,
+                                                       OFF_T, Int32, Int32,
+                                                       Logical));
+static CDFstatus ValidateVariableLinks PROTOARGs((struct CDFstruct *, vFILE *,
+                                                  Logical, Logical));
+static CDFstatus ValidateVariableValueLinks PROTOARGs((struct CDFstruct *,
+                                                       vFILE *, Int32, OFF_T,
+                                                       Logical));
 static struct CDRstruct64 CDR;
 static struct GDRstruct64 GDR;
 static int rVars, zVars;
@@ -69,10 +79,10 @@ static CDFstatus QuitCDF (char *why, OFF_T offset, int isize, int num,
     if (offset >= 0) {
 #if !defined(win32) && !defined(__MINGW32__)
       snprintf (texta, (size_t) sizeof(texta),
-	        " (@%lld) ", offset);
+	        " (@%lld) ", (long long) offset);
 #else
       snprintf (texta, (size_t) sizeof(texta),
-	        " (@%I64d) ", offset);
+	        " (@%I64d) ", (long long) offset);
 #endif
       strcatX (text, texta, 150);
     }
@@ -92,10 +102,12 @@ static CDFstatus QuitCDF (char *why, OFF_T offset, int isize, int num,
           text2[0] = (char) NUL;
 #if !defined(win32) && !defined(__MINGW32__)
           snprintf (text2, (size_t) sizeof(text2),
-		    "(%lld vs %lld)", *(OFF_T *)value1, *(OFF_T *)value2);
+		    "(%lld vs %lld)", *(long long *)value1, 
+                                      *(long long *)value2);
 #else
           snprintf (text2, (size_t) sizeof(text2),
-		    "(%I64d vs %I64d)", *(OFF_T *)value1, *(OFF_T *)value2);
+		    "(%I64d vs %I64d)", *(long long *)value1,
+                                        *(long long *)value2);
 #endif
           strcatX (text, text2, 150);
         } else { /* Each one is a string. */
@@ -122,10 +134,10 @@ static CDFstatus QuitCDF (char *why, OFF_T offset, int isize, int num,
           text2[0] = (char) NUL;
 #if !defined(win32) && !defined(__MINGW32__)
           snprintf (text2, (size_t) sizeof(text2),
-		    "(%lld)", *(OFF_T *)value1);
+		    "(%lld)", *(long long *)value1);
 #else
           snprintf (text2, (size_t) sizeof(text2),
-		    "(%I64d)", *(OFF_T *)value1);
+		    "(%I64d)", *(long long *)value1);
 #endif
           strcatX (text, text2, 150);
         } else {
@@ -225,7 +237,6 @@ STATICforIDL CDFstatus ValidateCDF64 (struct CDFstruct *CDF, vFILE *CDFfp,
         **********************************************************************/
         case AgrEDR_:
         case AzEDR_: {
-          Logical zEntry = (recordType == AzEDR_);
           offset = offset + recordSize;
           if (!SEEKv64(CDFfp,offset,vSEEK_SET)) return CRE;
 	  break;
@@ -349,14 +360,13 @@ STATICforIDL CDFstatus ValidateCDF64 (struct CDFstruct *CDF, vFILE *CDFfp,
 static CDFstatus ValidateCDR (vFILE *fp, OFF_T offset, Logical debug)
 {
   Int32 actualEncoding;
-  int i;
   CDFstatus status;
  
   if (debug) 
 #if defined(win32) || defined(__MINGW32__)
-    printf("  Checking CDR...@%I64d\n", offset);
+    printf("  Checking CDR...@%I64d\n", (long long) offset);
 #else
-    printf("  Checking CDR...@%lld\n", offset);
+    printf("  Checking CDR...@%lld\n", (long long) offset);
 #endif
   status = ReadCDR64 (fp, offset, 
                       CDR_RECORD, &CDR, NULL,
@@ -398,9 +408,9 @@ static CDFstatus ValidateGDR (vFILE *fp, OFF_T offset, Logical debug)
 
   if (debug) 
 #if defined(win32) || defined(__MINGW32__)
-    printf("  Checking GDR...@%I64d\n", offset);
+    printf("  Checking GDR...@%I64d\n", (long long) offset);
 #else
-    printf("  Checking GDR...@%lld\n", offset);
+    printf("  Checking GDR...@%lld\n", (long long) offset);
 #endif
   status = ReadGDR64 (fp, offset, 
                       GDR_RECORD, &GDR,
@@ -417,13 +427,13 @@ static CDFstatus ValidateGDR (vFILE *fp, OFF_T offset, Logical debug)
     return QuitCDF ("CDF(GDR): NrVars or their link is invalid ", offset,
                     4, 1, &(GDR.NrVars), 0, debug);
   if (GDR.NumAttr < 0 || (GDR.NumAttr > 0 && GDR.ADRhead < 1)) 
-    return QuitCDF ("CDF(GDR): number of attributes or their link is invalid ", offset,
+    return QuitCDF ("CDF(GDR): # of attributes or their link is invalid ", offset,
                     4, 1, &(GDR.NumAttr), 0, debug);
   if (GDR.rMaxRec < -1) 
     return QuitCDF ("CDF(GDR): max rVars record is invalid ", offset,
                     4, 1, &(GDR.rMaxRec), 0, debug);
   if (GDR.rNumDims < 0 || GDR.rNumDims > CDF_MAX_DIMS) 
-    return QuitCDF ("CDF(GDR): number of dimensions for rVars is invalid ", offset,
+    return QuitCDF ("CDF(GDR): # of dimensions for rVars is invalid ", offset,
                     4, 1, &(GDR.rNumDims), 0, debug);
   if (GDR.NzVars < 0 || (GDR.NzVars > 0 && GDR.zVDRhead < 1)) 
     return QuitCDF ("CDF(GDR): NzVars or their link is invalid ", offset,
@@ -450,9 +460,9 @@ static CDFstatus ValidateADR (struct CDFstruct *CDF, vFILE *fp, OFF_T offset,
 
   if (debug) 
 #if defined(win32) || defined(__MINGW32__)
-    printf("  Checking ADR...@%I64d\n", offset);
+    printf("  Checking ADR...@%I64d\n", (long long) offset);
 #else
-    printf("  Checking ADR...@%lld\n", offset);
+    printf("  Checking ADR...@%lld\n", (long long) offset);
 #endif
   status = ReadADR64 (fp, offset, 
                       ADR_RECORD, &ADR,
@@ -512,9 +522,9 @@ static CDFstatus ValidateAEDR (struct CDFstruct *CDF, vFILE *fp, OFF_T offset,
 
   if (debug)
 #if defined(win32) || defined(__MINGW32__)
-    printf("  Checking AEDR...@%I64d\n", offset);
+    printf("  Checking AEDR...@%I64d\n", (long long) offset);
 #else
-    printf("  Checking AEDR...@%lld\n", offset);
+    printf("  Checking AEDR...@%lld\n", (long long) offset);
 #endif
   status = ReadAEDR64 (fp, offset, 
                        AEDR_RECORD, &AEDR, NULL,
@@ -570,17 +580,16 @@ static CDFstatus ValidateVDR (struct CDFstruct *CDF, vFILE *fp, OFF_T offset,
 		              Logical zVar, Logical debug)
 {
   struct VDRstruct64 VDR;
-  void *padValue;
-  Int32 nDims, numVars;
+  Int32 numVars;
   int ix;
   CDFstatus status;
   size_t nBytes;
   
   if (debug) 
 #if defined(win32) || defined(__MINGW32__)
-    printf("  Checking VDR...@%I64d\n", offset);
+    printf("  Checking VDR...@%I64d\n", (long long) offset);
 #else
-    printf("  Checking VDR...@%lld\n", offset);
+    printf("  Checking VDR...@%lld\n", (long long) offset);
 #endif
   status = ReadVDR64 (CDF, fp, offset, zVar, 
                       VDR_RECORD, &VDR, NULL,
@@ -641,7 +650,8 @@ static CDFstatus ValidateVDR (struct CDFstruct *CDF, vFILE *fp, OFF_T offset,
 * ValidateVXR.
 ******************************************************************************/
 
-static CDFstatus ValidateVXR (vFILE *fp, OFF_T offset, Int32 lastRec, Logical debug)
+static CDFstatus ValidateVXR (vFILE *fp, OFF_T offset, Int32 lastRec,
+                              Logical debug)
 {
   struct VXRstruct64 VXR;
   int i;
@@ -650,9 +660,9 @@ static CDFstatus ValidateVXR (vFILE *fp, OFF_T offset, Int32 lastRec, Logical de
 
   if (debug) 
 #if defined(win32) || defined(__MINGW32__)
-    printf("  Checking VXR...@%I64d\n", offset);
+    printf("  Checking VXR...@%I64d\n", (long long) offset);
 #else
-    printf("  Checking VXR...@%lld\n", offset);
+    printf("  Checking VXR...@%lld\n", (long long) offset);
 #endif
   status = ReadVXR64 (fp, offset, 
                       VXR_RECORD, &VXR,
@@ -672,19 +682,20 @@ static CDFstatus ValidateVXR (vFILE *fp, OFF_T offset, Int32 lastRec, Logical de
                     4, 2, &(VXR.NusedEntries), &(VXR.Nentries), debug);
   if (VXR.VXRnext > 0) {
     if (VXR.Last[VXR.NusedEntries-1] > lastRec)
-      return QuitCDF ("CDF(VXR): a variable last record does not match in a Variable Index Record: ", offset,
-                      4, 2, &(VXR.Last[VXR.NusedEntries-1]), &lastRec, debug);
+      return QuitCDF ("CDF(VXR): a variable last record does not match in a Variable Index Record: ",
+                      offset, 4, 2, &(VXR.Last[VXR.NusedEntries-1]), &lastRec,
+                      debug);
     status = ValidateVXR (fp, VXR.VXRnext, lastRec, debug);
     if (status != CDF_OK) return status;
   } else if (VXR.VXRnext < 0) {
-      return QuitCDF ("CDF(VXR): a link offset to next record is negative in a Variable Index Record: ", offset,
-                      8, 1, &(VXR.VXRnext), 0, debug);
+      return QuitCDF ("CDF(VXR): a link offset to next record is negative in a Variable Index Record: ",
+                      offset, 8, 1, &(VXR.VXRnext), 0, debug);
   }
 
   for (i = 0; i < VXR.NusedEntries; ++i) {
     if (VXR.First[i] < 0 || VXR.Last[i] < 0 || VXR.First[i] > VXR.Last[i])
-      return QuitCDF ("CDF(VXR): entry value for first/last is invalid ", offset,
-                      4, 2, &(VXR.First[i]), &(VXR.Last[i]), debug);
+      return QuitCDF ("CDF(VXR): entry value for first/last is invalid ",
+                      offset, 4, 2, &(VXR.First[i]), &(VXR.Last[i]), debug);
     if (VXR.Offset[i] < 1) 
       return QuitCDF ("CDF(VXR): entry offset is invalid ", offset,
                       8, 1, &(VXR.Offset[i]), 0, debug);
@@ -712,9 +723,9 @@ static CDFstatus ValidateVVR (vFILE *fp, OFF_T offset, Logical debug)
 
   if (debug) 
 #if defined(win32) || defined(__MINGW32__)
-    printf("  Checking VVR...@%I64d\n", offset);
+    printf("  Checking VVR...@%I64d\n", (long long) offset);
 #else
-    printf("  Checking VVR...@%lld\n", offset);
+    printf("  Checking VVR...@%lld\n", (long long) offset);
 #endif
   status = ReadVVR64 (fp, offset, 
                       VVR_RECORDx, &VVR,
@@ -740,9 +751,9 @@ static CDFstatus ValidateUIR (vFILE *fp, OFF_T offset, Logical debug)
 
   if (debug) 
 #if defined(win32) || defined(__MINGW32__)
-    printf("  Checking UIR...@%I64d\n", offset);
+    printf("  Checking UIR...@%I64d\n", (long long) offset);
 #else
-    printf("  Checking UIR...@%lld\n", offset);
+    printf("  Checking UIR...@%lld\n", (long long) offset);
 #endif
   status = ReadUIR64 (fp, offset, 
                       UIR_RECORD, &UIR,
@@ -774,9 +785,9 @@ static CDFstatus ValidateCCR (vFILE *fp, OFF_T offset, Logical debug)
 
   if (debug) 
 #if defined(win32) || defined(__MINGW32__)
-    printf("  Checking CCR...@%I64d\n", offset);
+    printf("  Checking CCR...@%I64d\n", (long long) offset);
 #else
-    printf("  Checking CCR...@%lld\n", offset);
+    printf("  Checking CCR...@%lld\n", (long long) offset);
 #endif
   status = ReadCCR64 (fp, offset, 
                       CCR_RECORD, &CCR,
@@ -804,15 +815,14 @@ static CDFstatus ValidateCCR (vFILE *fp, OFF_T offset, Logical debug)
 static CDFstatus ValidateCPR (vFILE *fp, OFF_T offset, Logical debug)
 {
   struct CPRstruct64 CPR;
-  int i;
   CDFstatus status;
   long cType, cParms[1];
 
   if (debug) 
 #if defined(win32) || defined(__MINGW32__)
-    printf("  Checking CPR...@%I64d\n", offset);
+    printf("  Checking CPR...@%I64d\n", (long long) offset);
 #else
-    printf("  Checking CPR...@%lld\n", offset);
+    printf("  Checking CPR...@%lld\n", (long long) offset);
 #endif
   status = ReadCPR64 (fp, offset, 
                       CPR_RECORD, &CPR,
@@ -842,14 +852,13 @@ static CDFstatus ValidateCPR (vFILE *fp, OFF_T offset, Logical debug)
 static CDFstatus ValidateSPR (vFILE *fp, OFF_T offset, Logical debug)
 {
   struct SPRstruct64 SPR;
-  int i;
   CDFstatus status;
 
   if (debug) 
 #if defined(win32) || defined(__MINGW32__)
-    printf("  Checking SPR...@%I64d\n", offset);
+    printf("  Checking SPR...@%I64d\n", (long long) offset);
 #else
-    printf("  Checking SPR...@%lld\n", offset);
+    printf("  Checking SPR...@%lld\n", (long long) offset);
 #endif
   status = ReadSPR64 (fp, offset, 
                       SPR_RECORD, &SPR,
@@ -878,9 +887,9 @@ static CDFstatus ValidateCVVR (vFILE *fp, OFF_T offset, Logical debug)
 
   if (debug) 
 #if defined(win32) || defined(__MINGW32__)
-    printf("  Checking CVVR...@%I64d\n", offset);
+    printf("  Checking CVVR...@%I64d\n", (long long) offset);
 #else
-    printf("  Checking CVVR...@%lld\n", offset);
+    printf("  Checking CVVR...@%lld\n", (long long) offset);
 #endif
   status = ReadCVVR64 (fp, offset, 
                        CVVR_RECORDx, &CVVR,
@@ -904,10 +913,11 @@ static CDFstatus ValidateAttributeLinks (struct CDFstruct *CDF, vFILE *fp,
 {
   CDFstatus status;
   OFF_T offset, nextADR, AgrEDRhead, AzEDRhead;
-  Int32 num, numgrEntries, maxgrEntry, numzEntries, maxzEntry, scope;
+  Int32 num, numgrEntries, maxgrEntry, numzEntries, maxzEntry;
   int ix, *visit;
 
-  visit = (int *) cdf_AllocateMemory ((size_t)GDR.NumAttr * sizeof(Int32), NULL);
+  visit = (int *) cdf_AllocateMemory ((size_t)GDR.NumAttr * sizeof(Int32),
+                                      NULL);
   if (visit == NULL) return BAD_MALLOC;
   for (ix = 0; ix < GDR.NumAttr; ++ix) visit[ix] = 0;
   offset = GDR.ADRhead;
@@ -949,8 +959,8 @@ static CDFstatus ValidateAttributeLinks (struct CDFstruct *CDF, vFILE *fp,
   for (ix = 0; ix < GDR.NumAttr; ++ix) {
     if (visit[ix] == 0) {
       cdf_FreeMemory (visit, NULL);
-      return QuitCDF ("CDF: an attribute unreachable in attribute link: ", (OFF_T) -1,
-                      4, 1, &ix, 0, debug);
+      return QuitCDF ("CDF: an attribute unreachable in attribute link: ",
+                      (OFF_T) -1, 4, 1, &ix, 0, debug);
     }
   }
   cdf_FreeMemory (visit, NULL);
@@ -973,7 +983,8 @@ static CDFstatus ValidateAttributeEntryLink (struct CDFstruct *CDF, vFILE *fp,
   
   offset = EDRhead;
   lastNum = 0;
-  visits = (Int32 *) cdf_AllocateMemory ((size_t)numEntries * sizeof(Int32), NULL);
+  visits = (Int32 *) cdf_AllocateMemory ((size_t)numEntries * sizeof(Int32),
+                                         NULL);
   if (visits == NULL) return BAD_MALLOC;
   for (ix = 0; ix < numEntries; ++ix) visits[ix] = 0;
   ix = 0;
@@ -991,15 +1002,15 @@ static CDFstatus ValidateAttributeEntryLink (struct CDFstruct *CDF, vFILE *fp,
       for (iy = 0; iy < ix; ++iy) {
         if (visits[iy] == entryNum) {
           cdf_FreeMemory (visits, NULL);
-          return QuitCDF ("CDF: entry number is repeating in an attribute entry link: ", (OFF_T) -1,
-                          4, 1, &entryNum, 0, debug);
+          return QuitCDF ("CDF: entry # is repeating in an attr entry link: ",
+                          (OFF_T) -1, 4, 1, &entryNum, 0, debug);
         }
       }
     }
     if (ix == (int) numEntries) {
       cdf_FreeMemory (visits, NULL);
-      return QuitCDF ("CDF: number of entries is more than maximum in an attribute entry link: ", (OFF_T) -1,
-                      4, 1, &ix, 0, debug);
+      return QuitCDF ("CDF: # of entries is more than max in an attr link: ",
+                      (OFF_T) -1, 4, 1, &ix, 0, debug);
     }
     visits[ix] = entryNum;
     ++ix;
@@ -1008,8 +1019,8 @@ static CDFstatus ValidateAttributeEntryLink (struct CDFstruct *CDF, vFILE *fp,
   }
   if (lastNum != maxEntry) {
     cdf_FreeMemory (visits, NULL);
-    return QuitCDF ("CDF: last entry number is not the maximum entry number in  an attribute entry link: ", (OFF_T) -1,
-                    4, 2, &lastNum, &maxEntry, debug);
+    return QuitCDF ("CDF: last entry # is not the max entry # in an attr link: ",
+                    (OFF_T) -1, 4, 2, &lastNum, &maxEntry, debug);
   }
   cdf_FreeMemory (visits, NULL);
   return CDF_OK;
@@ -1023,7 +1034,7 @@ static CDFstatus ValidateVariableLinks (struct CDFstruct *CDF, vFILE *fp,
                                         Logical zVar, Logical debug)
 {
   CDFstatus status;
-  OFF_T offset, headVXR, tailVXR, nextVXR, nextVDR, cprOffset;
+  OFF_T offset, headVXR, tailVXR, nextVDR, cprOffset;
   Int32 num, lastRec, flags;
   int ix, numVars, *visit;
 
@@ -1068,11 +1079,11 @@ static CDFstatus ValidateVariableLinks (struct CDFstruct *CDF, vFILE *fp,
     if (visit[ix] == 0) {
       cdf_FreeMemory (visit, NULL);
       if (zVar)
-        return QuitCDF ("CDF: a zVariable unreachable in the variable chain: ", (OFF_T) -1,
-                        4, 1, &ix, 0, debug);
+        return QuitCDF ("CDF: a zVar unreachable in the variable chain: ",
+                        (OFF_T) -1, 4, 1, &ix, 0, debug);
       else
-        return QuitCDF ("CDF: a rVariable unreachable in the variable chain: ", (OFF_T) -1,
-                        4, 1, &ix, 0, debug);
+        return QuitCDF ("CDF: a rVar unreachable in the variable chain: ",
+                        (OFF_T) -1, 4, 1, &ix, 0, debug);
     }
   }
   cdf_FreeMemory (visit, NULL);
@@ -1084,18 +1095,18 @@ static CDFstatus ValidateVariableLinks (struct CDFstruct *CDF, vFILE *fp,
     if (status == CDF_OK) {
       if (num >= numVars) { 
         if (zVar)
-          return QuitCDF ("CDF(VDR): a zVariable unreachable in the variable chain: ", offset,
-                          4, 1, &num, 0, debug);
+          return QuitCDF ("CDF(VDR): a zVar unreachable in the variable chain: ",
+                          offset, 4, 1, &num, 0, debug);
         else
-          return QuitCDF ("CDF(VDR): a rVariable unreachable in the variable chain: ", offset,
-                          4, 1, &num, 0, debug);
+          return QuitCDF ("CDF(VDR): a rVar unreachable in the variable chain: ",
+                          offset, 4, 1, &num, 0, debug);
       } else {
         if (zVar) 
-          return QuitCDF ("CDF(VDR): a zVariable is repeated in the variable chain: ", offset,
-                          4, 1, &num, 0, debug);
+          return QuitCDF ("CDF(VDR): a zVar is repeated in the variable chain: ",
+                          offset, 4, 1, &num, 0, debug);
         else
-          return QuitCDF ("CDF(VDR): a rVariable unreachable in the variable chain: ", offset,
-                          4, 1, &num, 0, debug);
+          return QuitCDF ("CDF(VDR): a rVar unreachable in the variable chain: ",
+                          offset, 4, 1, &num, 0, debug);
       }
     }
   }
