@@ -1,5 +1,5 @@
 /******************************************************************************
-* Copyright 1996-2013 United States Government as represented by the
+* Copyright 1996-2014 United States Government as represented by the
 * Administrator of the National Aeronautics and Space Administration.
 * All Rights Reserved.
 ******************************************************************************/
@@ -394,9 +394,26 @@ va_dcl
 	 if (!Write32(fp,&(AEDR->rfuC))) return CWE;
 	 if (!Write32(fp,&(AEDR->rfuD))) return CWE;
 	 if (!Write32(fp,&(AEDR->rfuE))) return CWE;
-	 if (value != NULL) {
-	   if (!sX(WriteBuffer(CDF,fp,AEDR->DataType,
-			       AEDR->NumElems,value),&pStatus)) return pStatus;
+         if (value != NULL) {
+	   if (STRINGdataType(AEDR->DataType)) {
+	     size_t len; char *newValue = NULL;
+	     len = strlen ((char *)value);
+	     if ((int)len < (int) AEDR->NumElems) {
+	       int ix;
+	       newValue = (char *) cdf_AllocateMemory ((size_t) AEDR->NumElems,
+						       NULL);
+	       memcpy (newValue, (char *)value, len);
+	       for (ix = (int) len; ix < (int) AEDR->NumElems; ++ix)
+	         *(newValue+ix) = (char) ' ';
+	     }
+	     if (!sX(WriteBuffer(CDF,fp,AEDR->DataType,AEDR->NumElems,
+				 (newValue==NULL?value:(void *)newValue)),
+		     &pStatus))
+	       return pStatus;
+	     if (newValue != NULL) cdf_FreeMemory (newValue, NULL);
+	   } else
+	     if (!sX(WriteBuffer(CDF,fp,AEDR->DataType,
+				 AEDR->NumElems,value),&pStatus)) return pStatus;
 	 }
 	 break;
        }
@@ -409,8 +426,24 @@ va_dcl
 			  AEDR_NULL),&pStatus)) return pStatus;
 	 tOffset = offset + AEDR_VALUE_OFFSET;
 	 if (!SEEKv(fp,tOffset,vSEEK_SET)) return CWE;
-	 if (!sX(WriteBuffer(CDF,fp,dataType,
-			     numElems,value),&pStatus)) return pStatus;
+	 if (STRINGdataType(dataType)) {
+	   size_t len; char *newValue = NULL;
+	   len = strlen ((char *)value);
+	   if ((int)len < (int) numElems) {
+	     int ix;
+	     newValue = (char *) cdf_AllocateMemory ((size_t) numElems, NULL);
+	     memcpy (newValue, (char *)value, len);
+	     for (ix = (int) len; ix < (int) numElems; ++ix)
+	        *(newValue+ix) = (char) ' ';
+	   }
+	   if (!sX(WriteBuffer(CDF,fp,dataType,numElems,
+			       (newValue==NULL?value:(void *)newValue)),
+		   &pStatus))
+	     return pStatus;
+	   if (newValue != NULL) cdf_FreeMemory (newValue, NULL);
+	 } else
+	   if (!sX(WriteBuffer(CDF,fp,dataType,
+			       numElems,value),&pStatus)) return pStatus;
 	 break;
        }
        default: {
@@ -505,9 +538,26 @@ va_dcl
 	 }
 	 if (!Write32s(fp,VDR->DimVarys,(int)nDims)) return CWE;
 	 if (PADvalueBITset(VDR->Flags) && padValue != NULL) {
-	   if (!sX(WriteBuffer(CDF,fp,VDR->DataType,
-			       VDR->NumElems,
-			       padValue),&pStatus)) return pStatus;
+	   if (STRINGdataType(VDR->DataType)) {
+	     size_t len; char *newPad = NULL;
+	     len = strlen ((char *)padValue);
+	     if ((int)len < (int) VDR->NumElems) {
+	       int ix;
+	       newPad = (char *) cdf_AllocateMemory ((size_t) VDR->NumElems,
+						     NULL);
+	       memcpy (newPad, (char *)padValue, len);
+	       for (ix = (int) len; ix < (int) VDR->NumElems; ++ix)
+		 *(newPad+ix) = (char) ' ';
+	     }
+	     if (!sX(WriteBuffer(CDF,fp,VDR->DataType,VDR->NumElems,
+				 (newPad==NULL?padValue:(void *)newPad)),
+		     &pStatus))
+	       return pStatus;
+	     if (newPad != NULL) cdf_FreeMemory (newPad, NULL);
+	   } else
+	     if (!sX(WriteBuffer(CDF,fp,VDR->DataType,
+			         VDR->NumElems,
+			         padValue),&pStatus)) return pStatus;
 	 }
 	 break;
        }
@@ -588,8 +638,24 @@ va_dcl
 	   tOffset = offset + rVDR_PADVALUE_OFFSETb + (rNumDims*sizeof(Int32));
 	 }
 	 if (!SEEKv(fp,tOffset,vSEEK_SET)) return CWE;
-	 if (!sX(WriteBuffer(CDF,fp,dataType,
-			     numElems,padValue),&pStatus)) return pStatus;
+	 if (STRINGdataType(dataType)) {
+	   size_t len; char *newPad = NULL;
+	   len = strlen ((char *)padValue);
+	   if ((int)len < (int) numElems) {
+	     int ix;
+	     newPad = (char *) cdf_AllocateMemory ((size_t) numElems, NULL);
+	     memcpy (newPad, (char *)padValue, len);
+	     for (ix = (int) len; ix < (int) numElems; ++ix)
+	        *(newPad+ix) = (char) ' ';
+	   }
+	   if (!sX(WriteBuffer(CDF,fp,dataType,numElems,
+			       (newPad==NULL?padValue:(void *)newPad)),
+		   &pStatus))
+	     return pStatus;
+	   if (newPad != NULL) cdf_FreeMemory (newPad, NULL);
+	 } else
+	   if (!sX(WriteBuffer(CDF,fp,dataType,
+			       numElems,padValue),&pStatus)) return pStatus;
 	 break;
        }
        default: {
