@@ -45,6 +45,9 @@
 *                               the actual read/write bytes is within the 
 *                               buffer size.
 *   V4.12 12-Aug-10, M Liu      Fill 0s to each new cache in AllocateBuffer.
+*   V4.13 10-Jan-17, M Liu      Modified to use mkstemp for creating temporary
+*                               file for Unix-based systems. Also, change the
+*                               directory to which the file will be created.
 *
 ******************************************************************************/
 
@@ -54,6 +57,9 @@
 
 #include "cdflib.h"
 #include "cdflib64.h"
+#if defined(win32)
+#  include "errno.h"
+#endif
 
 /******************************************************************************
 * Local macros/typedef's.
@@ -80,11 +86,13 @@ BOO(useVmem,LoadVMemory((MemHandle)cache->ptr,TRUE),cache->ptr)
 #define CACHEbufferWRITEto(cache) cache->ptr
 #endif
 
+#define TmpFileTemplate "mycdftmp.XXXXXX"
+
 /******************************************************************************
 * Local function prototypes.
 ******************************************************************************/
 
-static FILE *OpenFile PROTOARGs((char *file_spec, char *a_mode));
+static FILE *CDFOpenFile PROTOARGs((char *file_spec, char *a_mode));
 static Logical FreeCache PROTOARGs((vCACHE *firstCache));
 static vCACHE *FindCache PROTOARGs((vFILE *vFp, long blockN));
 static Logical vRead PROTOARGs((
@@ -106,10 +114,10 @@ static Logical ExtendFile PROTOARGs((vFILE *vFp, long toBlockN));
 #endif
 
 /******************************************************************************
-* OpenFile.
+* CDFOpenFile.
 ******************************************************************************/
 
-static FILE *OpenFile (file_spec, a_mode)
+static FILE *CDFOpenFile (file_spec, a_mode)
 char *file_spec;
 char *a_mode;
 {
@@ -489,76 +497,164 @@ void *buffer;
 size_t nBytes;
 vFILE *vFp;
 {
-  int tryN, pid;
-  FILE *fp;
+  int tryN;
 #if defined(__MWERKS__)
   int ii;
 #endif
-#if defined(win32)
-  char *temp;
+  FILE *fp = NULL;
+  int writable;
+#if defined(unix)
+  int fileid;
 #endif
+#if defined(win32)
+  int err;
+#endif
+  int pid;
+
+  pid = GetMyPID();
+  if (pid == -1) {
+#if defined(win32)
+    pid = (int) _getpid();
+#else
+# if !defined(unix)
+    pid = (int) getpid();
+# endif
+#endif
+    SetMyPID (pid);
+#if !defined(unix)
+    srand((unsigned int)pid*time(NULL));
+#endif
+  }
   /****************************************************************************
   * Create the scratch file if necessary.  If so, the current file path is
   * actually the scratch directory to be used.
   ****************************************************************************/
   if (vFp->fp == NULL) {
-    long i; char *tmpPath, *originalPath; size_t pathLength;
+    long i; char *tmpPath; size_t pathLength;
     pathLength = strlen(vFp->path) + 1 + 8 + 1 + EXT_LEN;
     if (pathLength < DU_MAX_DIR_LEN) pathLength = DU_MAX_DIR_LEN;
     tmpPath = (char *) cdf_AllocateMemory ((size_t)pathLength + 1, NULL);
     if (tmpPath == NULL) return FALSE;
-    originalPath = (char *) cdf_AllocateMemory ((size_t)pathLength + 1, NULL);
-    if (originalPath == NULL) return FALSE;
-    pid = GetMyPID();
-    if (pid == -1) {
-#if defined(win32)
-      pid = (int) _getpid();
-#else
-      pid = (int) getpid();
-#endif
-      SetMyPID (pid);
-      srand((unsigned int)pid*time(NULL));
-    }
-    if (vFp->path != NULL && strlen(vFp->path) != 0) {
+    if (vFp->path != NULL && strlen(vFp->path) != 0) { 
       strcpyX (tmpPath, vFp->path, 0);
       AppendToDir (tmpPath, "");
-    } else {
-      /* Use the known tmp direcotry */
-#if defined(linux) || defined(unix)
-      strcpyX (tmpPath, "/tmp/", 0);
-#else
-#  if defined(win32)
-      temp = getenv("TEMP");
-      if (temp != NULL) {
-        strcpyX (tmpPath, temp, 0);
-        strcatX (tmpPath, "\\", 0);
-      } else {
-        temp = getenv("TMP");
-        if (temp != NULL) {
-          strcpyX (tmpPath, temp, 0);
-          strcatX (tmpPath, "\\", 0);
+#     if defined(unix) || defined(vms)
+        strcatX (tmpPath, TmpFileTemplate, 0);
+        fileid = mkstemp(tmpPath);
+        if (fileid != -1) fp = fdopen(fileid, "w+");
+        else {
+          for (i = 1; i <= MAX_TMP; i++) {
+            strcpyX (tmpPath, vFp->path, 0);
+            AppendToDir (tmpPath, "");
+            snprintf (EofS(tmpPath), (size_t) pathLength + 1 - strlen(tmpPath),
+                      "TMP%08ld.%s", (long)(rand()%100000000), vFp->scratchExt);
+            if (!IsReg(tmpPath)) {
+              fp = CDFOpenFile (tmpPath, WRITE_PLUS_a_mode);
+              if (fp != NULL) break;
+            }
+          }
         }
-      }
-#  else 
-#    if defined(vms)
-       strcpyX (tmpPath, "SYS$SCRATCH:", 0);
-#    else 
-       strcpyX (tmpPath, vFp->path, 0);
-#    endif
-#  endif
-#endif       
+#     else
+#       if defined(win32)
+          strcatX (tmpPath, TmpFileTemplate, 0);
+          err = _mktemp_s(tmpPath, (int)strlen(tmpPath)+1);
+          if (err == 0) {
+            fp = CDFOpenFile (tmpPath, WRITE_PLUS_a_mode);
+          } else {
+            if (err == EEXIST) {
+              int i1, i2;
+              for (i = 1; i <= MAX_TMP; i++) {
+                i1 = (int) (((double)rand() / (RAND_MAX + 1)) * 25) + (int) 'A';
+                i2 = (int) (((double)rand() / (RAND_MAX + 1)) * 25) + (int) 'A';
+                strcpyX (tmpPath, vFp->path, 0);
+                AppendToDir (tmpPath, "");
+                snprintf (EofS(tmpPath), (size_t) pathLength + 1 -
+                                         strlen(tmpPath),
+                          "TMP%c%c%5.5d.%s", i1, i2, rand(), vFp->scratchExt);
+                if (!IsReg(tmpPath)) {
+                  fp = CDFOpenFile (tmpPath, WRITE_PLUS_a_mode);
+                  if (fp != NULL) break;
+                }
+              }
+            }
+          }
+#       else
+          for (i = 1; i <= MAX_TMP; i++) {
+            strcpy (tmpPath, vFp->path);
+            AppendToDir (tmpPath, "");
+            snprintf (EofS(tmpPath), (size_t) pathLength + 1 - strlen(tmpPath),
+                      "TMP%08ld.%s", (long)(rand()%100000000), vFp->scratchExt);
+            if (!IsReg(tmpPath)) fp = CDFOpenFile (tmpPath, WRITE_PLUS_a_mode);
+            if (fp != NULL) break;
+          }
+#       endif
+#     endif
+    } else {
+      char *tmpFolder = NULL;
+      strcpy (tmpPath, "");
+#     if defined(unix) || defined(vms)
+        tmpFolder = (char *) cdf_AllocateMemory ((size_t)pathLength + 1, NULL);
+        if (tmpFolder == NULL) return FALSE;
+        writable = access(".", W_OK);
+        if (writable == 0) {
+          strcpy (tmpPath, TmpFileTemplate);
+          strcpy (tmpFolder, "");
+        } else {
+#         if defined(unix)
+            strcpy (tmpPath, "/tmp/");
+            strcpy (tmpFolder, tmpPath);
+#         else
+            strcpy (tmpPath, "SYS$SCRATCH:");
+            strcpy (tmpFolder, tmpPath);
+#         endif
+          strcatX (tmpPath, TmpFileTemplate, 0);
+        }
+        fileid = mkstemp(tmpPath);
+        if (fileid != -1) fp = fdopen(fileid, "w+");
+        else {
+          for (i = 1; i <= MAX_TMP; i++) {
+            strcpy (tmpPath, tmpFolder);
+            snprintf (EofS(tmpPath), (size_t) pathLength + 1 - strlen(tmpPath),
+                      "TMP%08ld.%s", (long)(rand()%100000000), vFp->scratchExt);
+            if (!IsReg(tmpPath)) {
+              fp = CDFOpenFile (tmpPath, WRITE_PLUS_a_mode);
+              if (fp != NULL) break;
+            }
+          }
+        }
+        if (tmpFolder != NULL) cdf_FreeMemory (tmpFolder, NULL);
+#     else
+#       if defined(win32)
+          strcatX (tmpPath, TmpFileTemplate, 0);
+          err = _mktemp_s(tmpPath, (int)strlen(tmpPath)+1 );
+          if (err == 0) {
+            fp = CDFOpenFile (tmpPath, WRITE_PLUS_a_mode);
+          } else {
+            if (err == EEXIST) {
+              int i1, i2;
+              for (i = 1; i <= MAX_TMP; i++) {
+                strcpy (tmpPath, "");
+                i1 = (int) (((double)rand() / (RAND_MAX + 1)) * 25) + (int) 'A';
+                i2 = (int) (((double)rand() / (RAND_MAX + 1)) * 25) + (int) 'A';
+                snprintf (EofS(tmpPath), (size_t) pathLength + 1 -
+                                         strlen(tmpPath),
+                          "TMP%c%c%5.5d.%s", i1, i2, rand(), vFp->scratchExt);
+                if (!IsReg(tmpPath)) {
+                  if (_access(tmpPath, 0) != 0) {
+                    fp = CDFOpenFile (tmpPath, WRITE_PLUS_a_mode);
+                    if (fp != NULL) break;
+                  }
+                }
+              }
+            }
+          }
+#       else
+          snprintf (EofS(tmpPath), (size_t) pathLength + 1 - strlen(tmpPath),
+                    "TMP%08ld.%s", (long)(rand()%100000000), vFp->scratchExt);
+          if (!IsReg(tmpPath)) fp = CDFOpenFile (tmpPath, WRITE_PLUS_a_mode);
+#       endif
+#     endif
     }
-    strcpyX (originalPath, tmpPath, 0);
-    for (i = 1; i <= MAX_TMP; i++) {
-       snprintf (EofS(tmpPath), (size_t) pathLength + 1 - strlen(tmpPath),
-                 "TMP%05ld.%s", (long)(rand()%100000), vFp->scratchExt);
-       if (!IsReg(tmpPath)) {
-	 fp = OpenFile (tmpPath, WRITE_PLUS_a_mode);
-	 if (fp != NULL) break; 
-       }
-       strcpyX (tmpPath, originalPath, 0);
-    }
-    cdf_FreeMemory (originalPath, NULL);
     if (fp == NULL) {
       cdf_FreeMemory (tmpPath, NULL);
       return FALSE;
@@ -567,7 +663,6 @@ vFILE *vFp;
       vFp->path = tmpPath;
       vFp->fp = fp;
     }
-    cdf_FreeMemory (originalPath, NULL);
   }
   /****************************************************************************
   * Tally a block write.
@@ -605,7 +700,7 @@ char *a_mode;           /* Access mode. */
   /****************************************************************************
   * Open the file.
   ****************************************************************************/
-  fp = OpenFile (file_spec, a_mode);
+  fp = CDFOpenFile (file_spec, a_mode);
   if (fp == NULL) return NULL;
 #if defined(vms)
   /****************************************************************************
@@ -653,7 +748,7 @@ char *a_mode;           /* Access mode. */
 	fclose (fp);
 	return NULL;
       }
-      fp = OpenFile (file_spec, a_mode);
+      fp = CDFOpenFile (file_spec, a_mode);
       if (fp == NULL) return NULL;
     }
   }
@@ -673,8 +768,7 @@ char *a_mode;           /* Access mode. */
     cdf_FreeMemory (vFp, NULL);
     fclose (fp);
     return NULL;
-  }
-  else
+  } else
     strcpyX (vFp->path, file_spec, 0);
   vFp->scratch = FALSE;
   vFp->error = FALSE;
@@ -759,8 +853,7 @@ char *extension;	/* Extension to use for the scratch file.  If NULL,
   if (vFp->path == NULL) {
     cdf_FreeMemory (vFp, NULL);
     return NULL;
-  }
-  else
+  } else
     strcpyX (vFp->path, BOO(directory == NULL,"",directory), 0);
   strcpyX (vFp->scratchExt, BOO(extension == NULL,"ich",extension), EXT_LEN);
   vFp->scratch = TRUE;
@@ -1372,7 +1465,7 @@ vSTATS *vStats;         /* Pointer to statistics structure. */
   * Delete the file (unless it was never created).
   ****************************************************************************/
   if (vFp->fp != NULL) {
-    if (!DeleteFile(vFp->path)) error = TRUE;
+    if (!CDFdeleteFile(vFp->path)) error = TRUE;
   }
   /****************************************************************************
   * Pass back statistics (if requested).
