@@ -46,6 +46,9 @@
 *                               sure the actual read/write bytes is within
 *                               the buffer size.
 *   V5.4  12-Aug-10, M Liu      Fill 0s to each new cache in AllocateBuffer.
+*   V5.5  10-Jan-17, M Liu      Modified to use mkstemp for creating temporary
+*                               file for Unix-based systems. Also, change the
+*                               directory to which the file will be created.
 *
 ******************************************************************************/
 
@@ -55,7 +58,9 @@
 
 #include "cdflib.h"
 #include "cdflib64.h"
-#include "errno.h"
+#if defined(win32)
+#  include "errno.h"
+#endif
 
 /******************************************************************************
 * Local macros/typedef's.
@@ -82,15 +87,17 @@ BOO(useVmem,LoadVMemory((MemHandle)cache->ptr,TRUE),cache->ptr)
 #define CACHEbufferWRITEto(cache) cache->ptr
 #endif
 
+#define TmpFileTemplate "mycdftmp.XXXXXX"
+
 int pid = -1;
 
 /******************************************************************************
 * Local function prototypes.
 ******************************************************************************/
 #if defined(win32) && (_FILE_OFFSET_BITS == 64)
-static int OpenFile PROTOARGs((char *file_spec, char *a_mode));
+static int CDFOpenFile PROTOARGs((char *file_spec, char *a_mode));
 #else
-static FILE *OpenFile PROTOARGs((char *file_spec, char *a_mode));
+static FILE *CDFOpenFile PROTOARGs((char *file_spec, char *a_mode));
 #endif
 
 static Logical FreeCache PROTOARGs((vCACHE *firstCache));
@@ -116,12 +123,12 @@ static Logical ExtendFile PROTOARGs((vFILE *vFp, long toBlockN));
 #endif
 
 /******************************************************************************
-* OpenFile.
+* CDFOpenFile.
 ******************************************************************************/
 #if defined(win32) && (_FILE_OFFSET_BITS == 64)
-static int OpenFile (file_spec, a_mode)
+static int CDFOpenFile (file_spec, a_mode)
 #else
-static FILE *OpenFile (file_spec, a_mode)
+static FILE *CDFOpenFile (file_spec, a_mode)
 #endif
 char *file_spec;
 char *a_mode;                   
@@ -557,101 +564,163 @@ vFILE *vFp;
   int ii;
 #endif
 #if defined(win32) && (_FILE_OFFSET_BITS == 64)
-  int fh;
+  int fh = -1;
 #else
-  FILE *fp;
+  FILE *fp = NULL;
+#endif
+  int writable;
+#if defined(unix)
+  int fileid;
 #endif
 #if defined(win32)
-  char *temp;
-#endif
-#if defined(unix)
-  int    ret, endian = 1;
-  long long tmpx;
-  union {
-    long long tmpTime;
-    unsigned int tmp2[2];
-  } totmp;
-  struct timeval nowtime;
+  int err;
 #endif
   /****************************************************************************
   * Create the scratch file if necessary.  If so, the current file path is
   * actually the scratch directory to be used.
   ****************************************************************************/
+  if (pid == -1) {
+#   if defined(win32)
+      pid = (int) _getpid();
+#   else
+      pid = (int) getpid();
+#   endif
+    srand((unsigned int)pid*time(NULL));
+  }  
 #if defined(win32) && (_FILE_OFFSET_BITS == 64)
   if (vFp->fh == 0) {
 #else
   if (vFp->fp == NULL) {
 #endif
-    long i; char *tmpPath, *originalPath; size_t pathLength;
+    long i; char *tmpPath = NULL; size_t pathLength;
     pathLength = strlen(vFp->path) + 1 + 8 + 1 + EXT_LEN;
     if (pathLength < DU_MAX_DIR_LEN) pathLength = DU_MAX_DIR_LEN;
     tmpPath = (char *) cdf_AllocateMemory ((size_t)pathLength + 1, NULL);
     if (tmpPath == NULL) return FALSE;
-    originalPath = (char *) cdf_AllocateMemory ((size_t)pathLength + 1, NULL);
-    if (originalPath == NULL) return FALSE;
-    if (pid == -1) {
-#if defined(win32)
-      pid = (int) _getpid();
-#else
-      pid = (int) getpid();
-#endif
-#if defined(unix)
-      ret = gettimeofday(&nowtime, NULL);
-      tmpx = (long long) nowtime.tv_sec*1000000LL + (int) nowtime.tv_usec;
-      tmpx = tmpx % 10000000000000LL;
-      totmp.tmpTime = (long long) pid * tmpx;
-      srand((unsigned int)(*(char *)&endian==1)?totmp.tmp2[0]:totmp.tmp2[1]);
-#else
-      srand((unsigned int)pid*time(NULL));
-#endif
-    }
     if (vFp->path != NULL && strlen(vFp->path) != 0) { 
       strcpyX (tmpPath, vFp->path, 0);
       AppendToDir (tmpPath, "");
-    } else {
-      /* Use the known tmp direcotry */
-#if defined(linux) || defined(unix) || defined(__CYGWIN__) || \
-    defined(__MINGw32__)
-      strcpyX (tmpPath, "/tmp/", 0);
-#else
-#  if defined(win32)
-      temp = getenv("TEMP");
-      if (temp != NULL) {
-        strcpyX (tmpPath, temp, 0);
-        strcatX (tmpPath, "\\", 0);
-      } else {
-        temp = getenv("TMP");
-        if (temp != NULL) {
-          strcpyX (tmpPath, temp, 0);
-          strcatX (tmpPath, "\\", 0);
+#     if defined(unix) || defined(vms)
+        strcatX (tmpPath, TmpFileTemplate, 0);
+        fileid = mkstemp(tmpPath);
+        if (fileid != -1) fp = fdopen(fileid, "w+");
+        else {
+          for (i = 1; i <= MAX_TMP; i++) {
+            strcpyX (tmpPath, vFp->path, 0);
+            AppendToDir (tmpPath, "");
+            snprintf (EofS(tmpPath), (size_t) pathLength + 1 - strlen(tmpPath),
+                      "TMP%08ld.%s", (long)(rand()%100000000), vFp->scratchExt);
+            if (!IsReg(tmpPath)) {
+              fp = CDFOpenFile (tmpPath, WRITE_PLUS_a_mode);
+              if (fp != NULL) break;
+            }
+          }
         }
-      }
-#  else
-#    if defined(vms)
-      strcpyX (tmpPath, "SYS$SCRATCH:", 0);
-#    else
-      strcpyX (tmpPath, vFp->path, 0);
-#    endif
-#  endif
-#endif
+#     else
+#       if defined(win32)
+          fh = -1;
+          strcatX (tmpPath, TmpFileTemplate, 0);
+          err = _mktemp_s(tmpPath, (int)strlen(tmpPath)+1);
+          if (err == 0) {
+            fh = CDFOpenFile (tmpPath, WRITE_PLUS_a_mode);
+          } else {
+            if (err == EEXIST) {
+              int i1, i2;
+              for (i = 1; i <= MAX_TMP; i++) {
+                fh = -1;
+                i1 = (int) (((double)rand() / (RAND_MAX + 1)) * 25) + (int) 'A';
+                i2 = (int) (((double)rand() / (RAND_MAX + 1)) * 25) + (int) 'A';
+                strcpyX (tmpPath, vFp->path, 0);
+                AppendToDir (tmpPath, "");
+                snprintf (EofS(tmpPath), (size_t) pathLength + 1 -
+                                         strlen(tmpPath),
+                          "TMP%c%c%5.5d.%s", i1, i2, rand(), vFp->scratchExt);
+                if (!IsReg(tmpPath)) {
+                  fh = CDFOpenFile (tmpPath, WRITE_PLUS_a_mode);
+                  if (fh != -1) break;
+                }
+              }
+            }
+          }
+#       else
+          for (i = 1; i <= MAX_TMP; i++) {
+            strcpy (tmpPath, vFp->path);
+            AppendToDir (tmpPath, "");
+            snprintf (EofS(tmpPath), (size_t) pathLength + 1 - strlen(tmpPath),
+                      "TMP%08ld.%s", (long)(rand()%100000000), vFp->scratchExt);
+            if (!IsReg(tmpPath)) fp = CDFOpenFile (tmpPath, WRITE_PLUS_a_mode);
+            if (fp != NULL) break;
+          }
+#       endif
+#     endif
+    } else {
+      char *tmpFolder = NULL;
+      strcpy (tmpPath, "");
+#     if defined(unix) || defined(vms)
+        tmpFolder = (char *) cdf_AllocateMemory ((size_t)pathLength + 1, NULL);
+        if (tmpFolder == NULL) return FALSE;
+        writable = access(".", W_OK);
+        if (writable == 0) {
+          strcpy (tmpPath, TmpFileTemplate);
+          strcpy (tmpFolder, "");
+        } else {
+#         if defined(unix)
+            strcpy (tmpPath, "/tmp/");
+            strcpy (tmpFolder, tmpPath);
+#         else
+            strcpy (tmpPath, "SYS$SCRATCH:");
+            strcpy (tmpFolder, tmpPath);
+#         endif
+          strcatX (tmpPath, TmpFileTemplate, 0);
+        }
+        fileid = mkstemp(tmpPath);
+        if (fileid != -1) fp = fdopen(fileid, "w+");
+        else {
+          for (i = 1; i <= MAX_TMP; i++) {
+            strcpy (tmpPath, tmpFolder);
+            snprintf (EofS(tmpPath), (size_t) pathLength + 1 - strlen(tmpPath),
+                      "TMP%08ld.%s", (long)(rand()%100000000), vFp->scratchExt);
+            if (!IsReg(tmpPath)) {
+              fp = CDFOpenFile (tmpPath, WRITE_PLUS_a_mode);
+              if (fp != NULL) break;
+            }
+          }
+        }
+        if (tmpFolder != NULL) cdf_FreeMemory (tmpFolder, NULL);
+#     else
+#       if defined(win32)
+          fh = -1;
+          strcatX (tmpPath, TmpFileTemplate, 0);
+          err = _mktemp_s(tmpPath, (int)strlen(tmpPath)+1 );
+          if (err == 0) {
+            fh = CDFOpenFile (tmpPath, WRITE_PLUS_a_mode);
+          } else {
+            if (err == EEXIST) {
+              int i1, i2;
+              for (i = 1; i <= MAX_TMP; i++) {
+                fh = -1;
+                strcpy (tmpPath, "");
+                i1 = (int) (((double)rand() / (RAND_MAX + 1)) * 25) + (int) 'A';
+                i2 = (int) (((double)rand() / (RAND_MAX + 1)) * 25) + (int) 'A';
+                snprintf (EofS(tmpPath), (size_t) pathLength + 1 -
+                                         strlen(tmpPath),
+                          "TMP%c%c%5.5d.%s", i1, i2, rand(), vFp->scratchExt);
+                if (!IsReg(tmpPath)) {
+                  if (_access(tmpPath, 0) != 0) {
+                    fh = CDFOpenFile (tmpPath, WRITE_PLUS_a_mode);
+                    if (fh != -1) break;
+                  }
+                }
+              }
+            }
+          }
+#       else
+          snprintf (EofS(tmpPath), (size_t) pathLength + 1 - strlen(tmpPath),
+                    "TMP%08ld.%s", (long)(rand()%100000000), vFp->scratchExt);
+          if (!IsReg(tmpPath)) fp = CDFOpenFile (tmpPath, WRITE_PLUS_a_mode);
+#       endif
+#     endif
     }
-    strcpyX (originalPath, tmpPath, 0);
-    for (i = 1; i <= MAX_TMP; i++) {
-       snprintf (EofS(tmpPath), (size_t) pathLength + 1 - strlen(tmpPath),
-                 "TMP%05ld.%s", (long)(rand()%100000), vFp->scratchExt);
-       if (!IsReg(tmpPath)) {
-#if defined(win32) && (_FILE_OFFSET_BITS == 64)
-         fh = OpenFile (tmpPath, WRITE_PLUS_a_mode);
-         if (fh != -1) break; 
-#else
-	 fp = OpenFile (tmpPath, WRITE_PLUS_a_mode);
-	 if (fp != NULL) break;
-#endif
-       }
-       strcpyX (tmpPath, originalPath, 0);
-/*       srand((unsigned int)pid*(time(NULL)+i-1)); */
-    }
-    cdf_FreeMemory (originalPath, NULL);
 #if defined(win32) && (_FILE_OFFSET_BITS == 64)
     if (fh == -1) {
 #else
@@ -1061,7 +1130,7 @@ char *a_mode;           /* Access mode. */
   /****************************************************************************
   * Open the file.
   ****************************************************************************/
-  fp = OpenFile (file_spec, a_mode);
+  fp = CDFOpenFile (file_spec, a_mode);
 #if defined(win32) && (_FILE_OFFSET_BITS == 64)
   if (fp == -1) return NULL;
 #else
@@ -1114,7 +1183,7 @@ char *a_mode;           /* Access mode. */
 	FCLOSE64 (fp);
 	return NULL;
       }
-      fp = OpenFile (file_spec, a_mode);
+      fp = CDFOpenFile (file_spec, a_mode);
       if (fp == NULL) return NULL;
     }
   }
@@ -1442,7 +1511,7 @@ vSTATS *vStats;         /* Pointer to statistics structure. */
 #else
   if (vFp->fp != NULL) {
 #endif
-    if (!DeleteFile(vFp->path)) error = TRUE;
+    if (!CDFdeleteFile(vFp->path)) error = TRUE;
   }
   /****************************************************************************
   * Pass back statistics (if requested).
