@@ -49,9 +49,9 @@ long dimSizes[1] = {0}, dimVary[1] = {VARY};
 long indices[1] = {0}, counts[1]= {1}, intervals[1] = {1};
 
 long long tt2000[8], mm[8];
-double year1=2008, month1=12, day1=31, hour1=23, minute1=59, second1=57, 
+double year1=2016, month1=12, day1=31, hour1=23, minute1=59, second1=57, 
        msec1=100, usec1=200, nsec1=300;
-double year=2008, month=12, day=31, hour=23, minute=59, second=57, 
+double year=2016, month=12, day=31, hour=23, minute=59, second=57, 
        msec=100, usec=200, nsec=300;
 double yearOut, monthOut, dayOut, hourOut, minuteOut, secondOut, msecOut, 
        usecOut, nsecOut;
@@ -149,24 +149,24 @@ for (ix= 0; ix < 8; ix++) {
   breakdownTT2000 (mm[ix], &yearOut, &monthOut, &dayOut,
                    &hourOut, &minuteOut, &secondOut, &msecOut,
                    &usecOut, &nsecOut);
-   if (year != yearOut) QuitCDF("11.1", status);
-   if (month != monthOut) QuitCDF("11.2", status);
-   if (day != dayOut) QuitCDF("11.3", status);
-   if (hour != hourOut) QuitCDF("11.4", status);
-   if (minute != minuteOut) QuitCDF("11.5", status);
-   if (second != secondOut) QuitCDF("11.6", status);
-   if (msec != msecOut) QuitCDF("11.7", status);
-   if (usec != usecOut) QuitCDF("11.8", status);
-   if (nsec != nsecOut) QuitCDF("11.9", status);
-   ++second;
-   if (second > 60) {
-     year = 2009;     
-     month = 1; 
-     day = 1;
-     hour = 0;
-     minute = 0;
-     second = 0;
-   }
+  if (year != yearOut) QuitCDF("11.1", status);
+  if (month != monthOut) QuitCDF("11.2", status);
+  if (day != dayOut) QuitCDF("11.3", status);
+  if (hour != hourOut) QuitCDF("11.4", status);
+  if (minute != minuteOut) QuitCDF("11.5", status);
+  if (second != secondOut) QuitCDF("11.6", status);
+  if (msec != msecOut) QuitCDF("11.7", status);
+  if (usec != usecOut) QuitCDF("11.8", status);
+  if (nsec != nsecOut) QuitCDF("11.9", status);
+  ++second;
+  if (second > 60) {
+    year = year + 1;     
+    month = 1; 
+    day = 1;
+    hour = 0;
+    minute = 0;
+    second = 0;
+  }
 }
 
 varnum = CDFgetVarNum (id, "myINT8");
@@ -239,24 +239,24 @@ for (ix= 0; ix < 8; ix++) {
                    &usecOut, &nsecOut);
   encodeTT2000 (mm[ix], string, 3);
   printf ("%s\n",string);
-   if (year1 != yearOut) QuitCDF("33.1", status);
-   if (month1 != monthOut) QuitCDF("33.2", status);
-   if (day1 != dayOut) QuitCDF("33.3", status);
-   if (hour1 != hourOut) QuitCDF("33.4", status);
-   if (minute1 != minuteOut) QuitCDF("33.5", status);
-   if (second1 != secondOut) QuitCDF("33.6", status);
-   if (msec1 != msecOut) QuitCDF("33.7", status);
-   if (usec1 != usecOut) QuitCDF("33.8", status);
-   if (nsec1 != nsecOut) QuitCDF("33.9", status);
-   ++second1;
-   if (second1 > 60) {
-     year1 = 2009;     
-     month1 = 1; 
-     day1 = 1;
-     hour1 = 0;
-     minute1 = 0;
-     second1 = 0;
-   }
+  if (year1 != yearOut) QuitCDF("33.1", status);
+  if (month1 != monthOut) QuitCDF("33.2", status);
+  if (day1 != dayOut) QuitCDF("33.3", status);
+  if (hour1 != hourOut) QuitCDF("33.4", status);
+  if (minute1 != minuteOut) QuitCDF("33.5", status);
+  if (second1 != secondOut) QuitCDF("33.6", status);
+  if (msec1 != msecOut) QuitCDF("33.7", status);
+  if (usec1 != usecOut) QuitCDF("33.8", status);
+  if (nsec1 != nsecOut) QuitCDF("33.9", status);
+  ++second1;
+  if (second1 > 60) {
+    year1 = year1 + 1;     
+    month1 = 1; 
+    day1 = 1;
+    hour1 = 0;
+    minute1 = 0;
+    second1 = 0;
+  }
 }
 
 /******************************************************************************
