@@ -1,5 +1,5 @@
 /******************************************************************************
-* Copyright 1996-2013 United States Government as represented by the
+* Copyright 1996-2014 United States Government as represented by the
 * Administrator of the National Aeronautics and Space Administration.
 * All Rights Reserved.
 ******************************************************************************/
@@ -257,8 +257,6 @@ int helpId;
   };
   static int iLineNs1[] = { 1, 1 };
   static int iLineNs2[] = { 1, 1, 1 };
-  static int iCols[2];
-  static int iLens[2];
   static int iCols1[] = { 18, 53 };
   static int iLens1[] = { 5, 4 };
   static int iCols2[] = { 11, 30, 53 };
