@@ -99,12 +99,12 @@ char *argV[];
     "page", "nopage", "update_valids", "noupdate_valids", "update_scales",
     "noupdate_scales", "zmode", "neg2posfp0", "noneg2posfp0",
     "update_monotonic", "noupdate_monotonic", "report", "cache", "about",
-    "statistics", "nostatistics", NULL
+    "statistics", "nostatistics", "epoch_monotonic", NULL
   };
   static int optRequired[] = {
     FALSE, FALSE, TRUE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE,
     FALSE, FALSE, FALSE, TRUE, FALSE, FALSE, FALSE, FALSE, TRUE, TRUE,
-    FALSE, FALSE, FALSE, 0
+    FALSE, FALSE, FALSE, FALSE, 0
   };
   static char *reportTokens[] = { "errors", "warnings", "informationals" };
 
@@ -235,6 +235,14 @@ char *argV[];
 	report[WARNs] = REPORTwarningsDEFAULT;
 	report[INFOs] = REPORTinfosDEFAULT;
       }
+      if (qop == NULL) return FALSE;
+      /***********************************************************************
+      * Check for `epoch_monotonic' qualifier.
+      ***********************************************************************/
+      if (qop->qualEntered[EPOCH_MONOTONICqual]) {
+        epochMonotonic = TRUE;
+      } else
+        epochMonotonic = FALSE;
       /************************************************************************
       * Free QOP memory and check for an error.
       ************************************************************************/
@@ -260,8 +268,13 @@ char *argV[];
   * Display information.
   ****************************************************************************/
   ParsePath (CDFpath, CDFdir, CDFname);
-  WriteOut (OUTfp, "Statistics for \"");
-  if (!NULstring(oSpec)) WriteOut (stdout, "Statistics for \"");
+  if (!epochMonotonic) {
+    WriteOut (OUTfp, "Statistics for \"");
+    if (!NULstring(oSpec)) WriteOut (stdout, "Statistics for \"");
+  } else {
+    WriteOut (OUTfp, "Statistics (for epoch monotonic) for \"");
+    if (!NULstring(oSpec)) WriteOut (stdout, "Statistics (for epoch monotonic) for \"");
+  }
   WriteOut (OUTfp, CDFname);
   if (!NULstring(oSpec)) WriteOut (stdout, CDFname);
   if (!EndsWithIgCase(CDFname, ".cdf"))
@@ -336,6 +349,7 @@ char *argV[];
 			      rVAR_MAXREC_, &Var.varMaxRec,
 			NULL_);
        if (!StatusHandlerStats(status)) return FALSE;
+       if (epochMonotonic && !CDFepochDataType(Var.dataTypeV)) continue;
        if (!SetupVar(&Var)) {
 	 FreeVarMem (&Var);
 	 return FALSE;
@@ -364,6 +378,7 @@ char *argV[];
 			      zVAR_MAXREC_, &Var.varMaxRec,
 			NULL_);
        if (!StatusHandlerStats(status)) return FALSE;
+       if (epochMonotonic && !CDFepochDataType(Var.dataTypeV)) continue;
        if (!SetupVar(&Var)) {
 	 FreeVarMem (&Var);
 	 return FALSE;
@@ -407,6 +422,9 @@ struct VarStruct *Var;
   long numElemsE;                 /* number of elements for attribute entry */
   void *temp;
   int dimN;
+  int virtual;
+  long numElms, dataType;
+
   /****************************************************************************
   * Initialize pointers for memory to be allocated.
   ****************************************************************************/
@@ -420,19 +438,33 @@ struct VarStruct *Var;
   Var->minINrange = NULL;
   Var->maxINrange = NULL;
   Var->buffer = NULL;
+  virtual = 0;
+  if (epochMonotonic) {
+    /**************************************************************************
+    * Check if this a virtual variable. If so, sets it.
+    **************************************************************************/
+    status = CDFlib (SELECT_, ATTR_NAME_, "VIRTUAL",
+			      BOO(Var->Z,zENTRY_,rENTRY_), Var->varN,
+		     GET_, BOO(Var->Z,zENTRY_NUMELEMS_,
+				      rENTRY_NUMELEMS_), &numElms,
+		     NULL_);
+    if (status == CDF_OK) virtual = 1;
+  }
   /****************************************************************************
   * Display heading line for this variable.
   ****************************************************************************/
   strcpyX (line, "\n", MAX_SCREENLINE_LEN);
   delim = PickDelimiter (Var->varName, strlen(Var->varName));
   snprintf (EofS(line), (size_t) sizeof(line)-strlen(line),
-	    "%3ld.  %c%s%c", Var->varN + 1, delim, Var->varName, delim);
+  	    "%3ld.  %c%s%c", Var->varN + 1, delim, Var->varName, delim);
+  snprintf (EofS(line), (size_t) sizeof(line)-strlen(line),
+  	    "%s", (virtual==1?" (V)":" "));
   if (Var->Z) {
     snprintf (EofS(line), (size_t) sizeof(line)-strlen(line),
 	      "   %ld:[", Var->numDims);
     if (Var->numDims > 0) {
       for (dimN = 0; dimN < Var->numDims; dimN++) {
-	 if (dimN > 0) strcatX (line, ",", MAX_SCREENLINE_LEN);
+    	 if (dimN > 0) strcatX (line, ",", MAX_SCREENLINE_LEN);
 	 snprintf (EofS(line), (size_t) sizeof(line)-strlen(line),
 		   "%ld", Var->dimSizes[dimN]);
       }
@@ -452,9 +484,25 @@ struct VarStruct *Var;
   /****************************************************************************
   * Return early if no records written.
   ****************************************************************************/
-  if (Var->varMaxRec == -1) {
-    WriteOut (OUTfp, "          No records.\n");
-    return TRUE;
+  if (Var->varMaxRec == -1 && epochMonotonic) {
+    /**************************************************************************
+    * Check if this a virtual variable. If so, handle it.
+    **************************************************************************/
+    if (virtual == 1) {
+      status = CDFlib (SELECT_, ATTR_NAME_, "COMPONENT_1",
+				BOO(Var->Z,zENTRY_,rENTRY_), Var->varN,
+		       GET_, BOO(Var->Z,zENTRY_NUMELEMS_,
+				  	rENTRY_NUMELEMS_), &numElms,
+			     BOO(Var->Z,zENTRY_DATATYPE_,
+				        rENTRY_DATATYPE_), &dataType,
+		       NULL_);
+      if (status != CDF_OK) return FALSE;
+      if (!HandleVirtual(Var)) return FALSE;
+        return TRUE;
+    } else {
+      WriteOut (OUTfp, "          No records.\n");
+      return TRUE;
+    }
   }
   /****************************************************************************
   * If range checking requested, get the valid min/max.
@@ -472,7 +520,7 @@ struct VarStruct *Var;
     else {
       if (!StatusHandlerStats(status)) return FALSE;
       temp = cdf_AllocateMemory ((size_t) (CDFelemSize(dataTypeE) * numElemsE),
-			     FatalError);
+			         FatalError);
       status = CDFlib (GET_, BOO(Var->Z,zENTRY_DATA_,rENTRY_DATA_), temp,
 		       NULL_);
       if (!StatusHandlerStats(status)) {
@@ -480,8 +528,8 @@ struct VarStruct *Var;
 	return FALSE;
       }
       Var->validmin = cdf_AllocateMemory ((size_t) (CDFelemSize(Var->dataTypeV) *
-						Var->numElemsV),
-				      FatalError);
+						    Var->numElemsV),
+					  FatalError);
       ConvertDataType (dataTypeE, numElemsE, temp, Var->dataTypeV,
 		       Var->numElemsV, Var->validmin);
       cdf_FreeMemory (temp, FatalError);
@@ -500,7 +548,7 @@ struct VarStruct *Var;
       else {
 	if (!StatusHandlerStats(status)) return FALSE;
 	temp = cdf_AllocateMemory ((size_t) (CDFelemSize(dataTypeE) * numElemsE),
-			       FatalError);
+				   FatalError);
 	status = CDFlib (GET_, BOO(Var->Z,zENTRY_DATA_,rENTRY_DATA_), temp,
 			 NULL_);
 	if (!StatusHandlerStats(status)) {
@@ -508,8 +556,8 @@ struct VarStruct *Var;
 	  return FALSE;
 	}
 	Var->validmax = cdf_AllocateMemory ((size_t) (CDFelemSize(Var->dataTypeV) *
-						  Var->numElemsV),
-					FatalError);
+						      Var->numElemsV),
+					    FatalError);
 	ConvertDataType (dataTypeE, numElemsE, temp, Var->dataTypeV,
 			 Var->numElemsV, Var->validmax);
 	cdf_FreeMemory (temp, FatalError);
@@ -580,7 +628,7 @@ struct VarStruct *Var;
   /****************************************************************************
   * Read each record and calculate statistics.
   ****************************************************************************/
-  if (!CALCstat(Var)) return FALSE;
+  if (!CALCstat(Var, FALSE)) return FALSE;
   /****************************************************************************
   * Return - note that memory allocated will be freed by caller.
   ****************************************************************************/
@@ -595,18 +643,18 @@ void FreeVarMem (Var)
 struct VarStruct *Var;
 {
   if (Var->validmin != NULL) cdf_FreeMemory (Var->validmin,
-					 FatalError);
+					     FatalError);
   if (Var->validmax != NULL) cdf_FreeMemory (Var->validmax,
-					 FatalError);
+					     FatalError);
   if (Var->fillval != NULL) cdf_FreeMemory (Var->fillval, FatalError);
   if (Var->format != NULL) cdf_FreeMemory (Var->format, FatalError);
   if (Var->min != NULL) cdf_FreeMemory (Var->min, FatalError);
   if (Var->max != NULL) cdf_FreeMemory (Var->max, FatalError);
   if (Var->last != NULL) cdf_FreeMemory (Var->last, FatalError);
   if (Var->minINrange != NULL) cdf_FreeMemory (Var->minINrange,
-					   FatalError);
+					       FatalError);
   if (Var->maxINrange != NULL) cdf_FreeMemory (Var->maxINrange,
-					   FatalError);
+					       FatalError);
   if (Var->buffer != NULL) cdf_FreeMemory (Var->buffer, FatalError);
   return;
 }
@@ -758,78 +806,78 @@ char **argV[];
       * Ok.
       ************************************************************************/
       case OKin: {
-		int n;
-		char tempS1[1+1];
-		/**********************************************************************
-		* Get the value of each control.
-		**********************************************************************/
-		GetIText ((Handle) controlHs[CDFTEXTin], CDFtext);
-		GetIText ((Handle) controlHs[OUTTEXTin], outText);
-		GetIText ((Handle) controlHs[CACHEin], cacheText);
-		pageOutput = GetCtlValue (controlHs[PAGEin]);
-		useFormat = GetCtlValue (controlHs[FORMATin]);
-		rangeCheck = GetCtlValue (controlHs[RANGEin]);
-		useFillval = GetCtlValue (controlHs[FILLin]);
-		negToPos = GetCtlValue (controlHs[NEGZin]);
-		reportInfos = GetCtlValue (controlHs[INFOin]);
-		reportWarns = GetCtlValue (controlHs[WARNin]);
-		reportErrors = GetCtlValue (controlHs[ERRORin]);
-		updateValids = GetCtlValue (controlHs[VALIDin]);
-		updateScales = GetCtlValue (controlHs[SCALEin]);
-		updateMono = GetCtlValue (controlHs[MONOin]);
-		dispStats = GetCtlValue (controlHs[STATSin]);
-		for (zMode = 0; zMode < 3; zMode++) {
-		   if (GetCtlValue(controlHs[ZMODEinBASE+zMode])) break;
-		}
-		/**********************************************************************
-		* Build argc/argv.
-		**********************************************************************/
+	int n;
+	char tempS1[1+1];
+	/**********************************************************************
+	* Get the value of each control.
+	**********************************************************************/
+	GetIText ((Handle) controlHs[CDFTEXTin], CDFtext);
+	GetIText ((Handle) controlHs[OUTTEXTin], outText);
+	GetIText ((Handle) controlHs[CACHEin], cacheText);
+	pageOutput = GetCtlValue (controlHs[PAGEin]);
+	useFormat = GetCtlValue (controlHs[FORMATin]);
+	rangeCheck = GetCtlValue (controlHs[RANGEin]);
+	useFillval = GetCtlValue (controlHs[FILLin]);
+	negToPos = GetCtlValue (controlHs[NEGZin]);
+	reportInfos = GetCtlValue (controlHs[INFOin]);
+	reportWarns = GetCtlValue (controlHs[WARNin]);
+	reportErrors = GetCtlValue (controlHs[ERRORin]);
+	updateValids = GetCtlValue (controlHs[VALIDin]);
+	updateScales = GetCtlValue (controlHs[SCALEin]);
+	updateMono = GetCtlValue (controlHs[MONOin]);
+	dispStats = GetCtlValue (controlHs[STATSin]);
+	for (zMode = 0; zMode < 3; zMode++) {
+	   if (GetCtlValue(controlHs[ZMODEinBASE+zMode])) break;
+	}
+	/**********************************************************************
+	* Build argc/argv.
+	**********************************************************************/
         *argC = 14 + BOO(NULpString(CDFtext),0,1) +
 		     BOO(NULpString(outText),0,2) +
 		     BOO(NULpString(cacheText),0,2);
         *argV = (char **) cdf_AllocateMemory ((size_t)*argC * sizeof(char *),
 					  FatalError);
-		n = 0;
-		MAKEstrARGv (argV, n, pgmName)
-		if (!NULpString(CDFtext)) {
-		  PtoCstr (CDFtext);
-		  MAKEstrARGv (argV, n, (char *) CDFtext)
-		  CtoPstr ((char *) CDFtext);
-		}
-		MAKEbooARGv (argV, n, pageOutput, "-page", "-nopage")
-		MAKEbooARGv (argV, n, useFormat, "-format", "-noformat")
-		MAKEbooARGv (argV, n, rangeCheck, "-range", "-norange")
-		MAKEbooARGv (argV, n, useFillval, "-fill", "-nofill")
-		MAKEbooARGv (argV, n, negToPos, "-neg2posfp0", "-noneg2posfp0")
-		MAKEbooARGv (argV, n, updateValids, "-update_valids",
-				     "-noupdate_valids")
-		MAKEbooARGv (argV, n, updateScales, "-update_scales",
-				     "-noupdate_scales")
-		MAKEbooARGv (argV, n, updateMono, "-update_monotonic",
-				     "-noupdate_monotonic")
-		MAKEbooARGv (argV, n, dispStats, "-statistics", "-nostatistics")
-		MAKEstrARGv (argV, n, "-zmode")
-		snprintf (tempS1, (size_t) sizeof(tempS1), "%d", zMode);
-		MAKEstrARGv (argV, n, tempS1)
-		MAKEstrARGv (argV, n, "-report")
-		MAKEstrARGv (argV, n, StatusCodeReportOptions(reportErrors,
-						      reportWarns,
-						      reportInfos))
-		if (!NULpString(outText)) {
-		  MAKEstrARGv (argV, n, "-output")
-		  PtoCstr (outText);
-		  MAKEstrARGv (argV, n, (char *) outText)
-		  CtoPstr ((char *) outText);
-		}
-		if (!NULpString(cacheText)) {
-		  MAKEstrARGv (argV, n, "-cache")
-		  PtoCstr (cacheText);
-		  MAKEstrARGv (argV, n, (char *) cacheText)
-		  CtoPstr ((char *) cacheText);
-		}
-		/**********************************************************************
-		* Close the dialog and return.
-		**********************************************************************/
+	n = 0;
+	MAKEstrARGv (argV, n, pgmName)
+	if (!NULpString(CDFtext)) {
+	  PtoCstr (CDFtext);
+	  MAKEstrARGv (argV, n, (char *) CDFtext)
+	  CtoPstr ((char *) CDFtext);
+	}
+	MAKEbooARGv (argV, n, pageOutput, "-page", "-nopage")
+	MAKEbooARGv (argV, n, useFormat, "-format", "-noformat")
+	MAKEbooARGv (argV, n, rangeCheck, "-range", "-norange")
+	MAKEbooARGv (argV, n, useFillval, "-fill", "-nofill")
+	MAKEbooARGv (argV, n, negToPos, "-neg2posfp0", "-noneg2posfp0")
+	MAKEbooARGv (argV, n, updateValids, "-update_valids",
+			     "-noupdate_valids")
+	MAKEbooARGv (argV, n, updateScales, "-update_scales",
+			     "-noupdate_scales")
+	MAKEbooARGv (argV, n, updateMono, "-update_monotonic",
+			     "-noupdate_monotonic")
+	MAKEbooARGv (argV, n, dispStats, "-statistics", "-nostatistics")
+	MAKEstrARGv (argV, n, "-zmode")
+	snprintf (tempS1, (size_t) sizeof(tempS1), "%d", zMode);
+	MAKEstrARGv (argV, n, tempS1)
+	MAKEstrARGv (argV, n, "-report")
+	MAKEstrARGv (argV, n, StatusCodeReportOptions(reportErrors,
+					      reportWarns,
+					      reportInfos))
+	if (!NULpString(outText)) {
+	  MAKEstrARGv (argV, n, "-output")
+	  PtoCstr (outText);
+	  MAKEstrARGv (argV, n, (char *) outText)
+	  CtoPstr ((char *) outText);
+	}
+	if (!NULpString(cacheText)) {
+	  MAKEstrARGv (argV, n, "-cache")
+	  PtoCstr (cacheText);
+	  MAKEstrARGv (argV, n, (char *) cacheText)
+	  CtoPstr ((char *) cacheText);
+	}
+	/**********************************************************************
+	* Close the dialog and return.
+	**********************************************************************/
         CloseDialog (dialogP);
 #ifdef __MWERKS__
         DisposeRoutineDescriptor (FilterDialogQOPsoUPP);
@@ -844,12 +892,12 @@ char **argV[];
         int n;
         *argC = 1;
         *argV = (char **) cdf_AllocateMemory ((size_t)*argC * sizeof(char *), FatalError);
-		n = 0;
-		MAKEstrARGv (argV, n, pgmName)
-		CloseDialog (dialogP);
+	n = 0;
+	MAKEstrARGv (argV, n, pgmName)
+	CloseDialog (dialogP);
 #ifdef __MWERKS__
         DisposeRoutineDescriptor (FilterDialogQOPsoUPP);
-		DisposeRoutineDescriptor (OutlineDefaultButtonUPP);
+	DisposeRoutineDescriptor (OutlineDefaultButtonUPP);
 #endif
         return TRUE;
       }
@@ -860,29 +908,29 @@ char **argV[];
         CloseDialog (dialogP);
 #ifdef __MWERKS__
         DisposeRoutineDescriptor (FilterDialogQOPsoUPP);
-		DisposeRoutineDescriptor (OutlineDefaultButtonUPP);
+	DisposeRoutineDescriptor (OutlineDefaultButtonUPP);
 #endif
         return FALSE;
       /************************************************************************
       * Select CDF specification.
       ************************************************************************/
       case CDFSELECTin: {
-		StandardFileReply CDFreply;
-		char CDFpath[DU_MAX_PATH_LEN+1];
+	StandardFileReply CDFreply;
+	char CDFpath[DU_MAX_PATH_LEN+1];
 #ifndef __MWERKS__
-		StandardGetFile (FilterForCDFs, -1, NULL, &CDFreply);
+	StandardGetFile (FilterForCDFs, -1, NULL, &CDFreply);
 #else
-		FilterForCDFsUPP = NewFileFilterProc((ProcPtr) FilterForCDFs);
-		StandardGetFile (FilterForCDFsUPP, -1, NULL, &CDFreply);
-		DisposeRoutineDescriptor (FilterForCDFsUPP);
+	FilterForCDFsUPP = NewFileFilterProc((ProcPtr) FilterForCDFs);
+	StandardGetFile (FilterForCDFsUPP, -1, NULL, &CDFreply);
+	DisposeRoutineDescriptor (FilterForCDFsUPP);
 #endif
-		if (CDFreply.sfGood && !CDFreply.sfIsFolder && !CDFreply.sfIsVolume) {
-		  BuildMacPath (&CDFreply.sfFile, CDFpath, TRUE);
-		  CDFtext[0] = strlen (CDFpath);
-		  strcpyX ((char *) &CDFtext[1], CDFpath, 255);
-		  SetIText ((Handle) controlHs[CDFTEXTin], CDFtext);
-		}
-		break;
+	if (CDFreply.sfGood && !CDFreply.sfIsFolder && !CDFreply.sfIsVolume) {
+	  BuildMacPath (&CDFreply.sfFile, CDFpath, TRUE);
+	  CDFtext[0] = strlen (CDFpath);
+	  strcpyX ((char *) &CDFtext[1], CDFpath, 255);
+	  SetIText ((Handle) controlHs[CDFTEXTin], CDFtext);
+	}
+	break;
       }
       /************************************************************************
       * Select output file.
@@ -890,17 +938,17 @@ char **argV[];
       * an iBeam (instead of returning it to what it was).
       ************************************************************************/
       case OUTSELECTin: {
-		StandardFileReply outReply;
-		char outPath[DU_MAX_PATH_LEN+1], prompt[] = "Enter skeleton table:";
-		StandardPutFile (CtoPstr(prompt), CtoPstr(""), &outReply);
-		if (outReply.sfGood && !outReply.sfIsFolder && !outReply.sfIsVolume) {
-		  BuildMacPath (&outReply.sfFile, outPath, TRUE);
-		  outText[0] = strlen (outPath);
-		  strcpyX ((char *) &outText[1], outPath, 255);
-		  SetIText ((Handle) controlHs[OUTTEXTin], outText);
-		}
-		SetCursor (&(qd.arrow));
-		break;
+	StandardFileReply outReply;
+	char outPath[DU_MAX_PATH_LEN+1], prompt[] = "Enter skeleton table:";
+	StandardPutFile (CtoPstr(prompt), CtoPstr(""), &outReply);
+	if (outReply.sfGood && !outReply.sfIsFolder && !outReply.sfIsVolume) {
+	  BuildMacPath (&outReply.sfFile, outPath, TRUE);
+	  outText[0] = strlen (outPath);
+	  strcpyX ((char *) &outText[1], outPath, 255);
+	  SetIText ((Handle) controlHs[OUTTEXTin], outText);
+	}
+	SetCursor (&(qd.arrow));
+	break;
       }
       /************************************************************************
       * Check boxes.
